OC.L10N.register(
    "spreed",
    {
    "a conversation" : "محادثة",
    "(Duration %s)" : "(المدة الزمنية %s)",
    "You attended a call with {user1}" : "لقد حضرت مكالمة مع {user1}",
    "_%n guest_::_%n guests_" : ["%n ضيف","%n ضيف","%n ضيف","%n ضيف","%n ضيف","%nضيف"],
    "You attended a call with {user1} and {user2}" : "لقد حضرت مكالمة مع {user1} و {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "لقد حضرت مكالمة مع {user1} و {user2} و {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "لقد حضرت مكالمة مع {user1} و {user2} و {user3} و {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "لقد حضرت مكالمة مع {user1} و {user2} و {user3} و {user4} و {user5}",
    "_%n other_::_%n others_" : [" %n لايوجد آخرون"," %n شخص واحد","%n شخصان آخران","%n  بضعة أشخاص آخرين","%n  العديد من الأشخاص الآخرين","%n آخرون"],
    "{actor} invited you to {call}" : "{actor} يدعوك إلى {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "تم دعوتك للإنضمام إلى <strong>المحادثة</strong> أو <strong>المكالمة</strong>",
    "Other activities" : "أنشطة أخرى",
    "Talk" : "التحدث",
    "Guest" : "ضيف",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## مرحبًا بك في تطبيق \"المحادثة\" Talk من نكست كلاود! \nفي هذه المحادثة، سيتم إخطارك بالميزات الجديدة المتوفرة في التطبيق.",
    "## New in Talk %s" : "## الجديد في تطبيق \"المحادثة\" %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- بإمكانك إستعمال متصفح مايكروسوفت ايدج و سفاري الآن للانضمام إلى المكالمات الصوتية والفيديو",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- أصبحت المحادثات الفردية مستمرة الآن ولا يمكن تحويلها صدفة إلى محادثات جماعية. أيضًا عندما يغادر أحد المشاركين المحادثة، لن يتم حذف المحادثة تلقائيًا. فقط إذا غادر كلا المشاركين، سيتم حذف المحادثة من الخادم",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- يمكنك الآن تنبيه جميع المشاركين بنشر \"@all\" في الدردشة",
    "- With the \"arrow-up\" key you can repost your last message" : "باستخدام مفتاح \"السهم للأعلى\" بإمكانك إعادة نشر رسالتك الأخيرة ",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- يمكن أن يحتوي Talk الآن على أوامر ، أرسل \"مساعدة\" كرسالة دردشة لمعرفة ما إذا كان المسؤول قد قام بتهيئة بعضها",
    "- With projects you can create quick links between conversations, files and other items" : "- باستخدام المشاريع، يمكنك إنشاء روابط سريعة بين المحادثات والملفات والعناصر الأخرى",
    "- You can now mention guests in the chat" : "يمكنك الآن الإشارة إلى الضيوف في الدردشة",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- يمكن أن يكون للمحادثات الآن ساحة للانتظار. سيسمح هذا للمنسقين بالانضمام إلى الدردشة والاتصال بالفعل للتحضير للاجتماع، بينما يتعين على المستخدمين والضيوف الانتظار",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- يمكنك الآن الرد مباشرة على الرسائل مما يمنح المستخدمين الآخرين مجالًا أوسع لمعرفة موضوع رسالتك",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- سيؤدي البحث الآن عن المحادثات والمشاركين إلى تصفية محادثاتك الحالية أيضًا، مما يسهل كثيرًا العثور على المحادثات السابقة",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- يمكنك الآن إضافة مجموعات مستخدمين مخصصة إلى المحادثات عند تثبيت تطبيق circles",
    "- Check out the new grid and call view" : "- تحقق من الشبكة الجديدة وعرض المكالمة",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- يمكنك الآن رفع الملفات وسحبها مباشرة من جهازك إلى الدردشة",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- يتم الآن فتح الملفات المشتركة مباشرة داخل عرض الدردشة باستخدام تطبيقات العرض",
    "- You can now search for chats and messages in the unified search in the top bar" : "- يمكنك الآن البحث عن الدردشات والرسائل في البحث الموحد في الشريط العلوي",
    "- Spice up your messages with emojis from the emoji picker" : " - أضف على رسائلك الرموز التعبيرية",
    "- You can now change your camera and microphone while being in a call" : "- يمكنك الآن تغيير الكاميرا والميكروفون أثناء المكالمة",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- اضف لمحادثاتك بعض المحتوى مع وصف وافتحها حتى يتمكن المستخدمون المسجلون من العثور عليها والانضمام إليها",
    "- See a read status and send failed messages again" : "- انظر لحالة القراءة وارسل الرسائل التي فشل إرسالها مره أخرى. ",
    "- Raise your hand in a call with the R key" : "- ارفع يدك في المكالمة باستخدام مفتاح R.",
    "- Join the same conversation and call from multiple devices" : "- انضم إلى نفس المحادثة واتصل من أجهزة متعددة",
    "- Send voice messages, share your location or contact details" : "- إرسال رسائل صوتية، مشاركة موقعك أو تفاصيل الاتصال",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- أضف مجموعات إلى محادثة وسيتم تلقائيًا إضافة أعضاء المجموعة الجدد كمشاركين",
    "- A preview of your audio and video is shown before joining a call" : "- يتم عرض معاينة الصوت والفيديو قبل الانضمام إلى مكالمة",
    "- You can now blur your background in the newly designed call view" : "- يمكنك الآن طمس الخلفية في عرض المكالمات المصمم حديثًا",
    "- Moderators can now assign general and individual permissions to participants" : "- يمكن للمشرفين الآن تعيين أذونات عامة وفردية للمشاركين",
    "- You can now react to chat messages" : "- بإمكانك الآن التفاعل مع رسائل الدردشة",
    "- In the sidebar you can now find an overview of the latest shared items" : "- يمكنك الآن العثور في الشريط الجانبي على لمحة عن أحدث العناصر التي تمّت مُشارَكتها",
    "- Use a poll to collect the opinions of others or settle on a date" : "- استعمل استبياناً لجمع آراء الآخرين أو الاتفاق على تاريخ معين",
    "- Configure an expiration time for chat messages" : "- عيّن زمناً لانتهاء صلاحية رسائل الدردشة",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- إبدأ مكالمات بدون إعلام الآخرين المشتركين في محادثات المجموعات الكبيرة. يُمكنك إرسال إشعارٍ بالمحادثة على الخاص بمجرد أن تبدأ المكالمة.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- أرسِل رسائل دردشتك غير المستعجلة دون داعٍ لإزعاج المستلمين بإشعارت فورية",
    "- Emojis can now be autocompleted by typing a \":\"" : "- أصبح الاستكمال الآلي للإيموجي emoji الآن ممكناً؛ و ذلك بكتابة علامة الشارحة \":\"",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- إربط العناصر المتعددة باستعمال اللاقط الذكي الجديد؛ و ذلك بكتابة علامة الشَّرْطَة المائلة \"/\"",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- يمكن للمشرفين الآن فتح غرف جانبية (يتطلب ذلك واجهة خلفية عالية الآداء)",
    "- Calls can now be recorded (requires the High-performance backend)" : "- يمكن الآن تسجيل المكالمات (يتطلب ذلك واجهة خلفية عالية الأداء)",
    "- Conversations can now have an avatar or emoji as icon" : "- صار بإمكان المحادثات أن تحمل صورة رمزية Avatar أو إيموجي emoji كأيقونة",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- الخلفيات الظاهرية أصبحت متاحةً الآن في محادثات الفيديو بالإضافة إلى تضبيب الخلفية",
    "- Reactions are now available during calls" : "- الاستجابات Reactions ممكنة  الآن في أثناء المكالمات",
    "- Typing indicators show which users are currently typing a message" : "- مؤشرات الطباعة Typing indicators تظهر على النص أو الرسالة في موضع الإدخال الحالي لكل مستخدم ",
    "- Groups can now be mentioned in chats" : "- صار بالإمكان الإشارة إلى mention المجموعات في الدردشة",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- المكالمات أثناء تسجيلها يمكن آليّاً تحويلها إلى نص transcribe إذا ما تمّ تسجيل تطبيقٍ لمُزوّد ترجمةٍ translation provider app",
    "- Chat messages can be translated if a translation provider app is registered" : "- رسائل الدردشة يمكن ترجمتها إذا ما تمّ تسجيل تطبيقٍ لمُزوّد ترجمةٍ translation provider app",
    "- **Markdown** can now be used in _chat_ messages" : "- **تنسيق ماركداون** يمكن استعماله الآن في _رسائل_الدردشة",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- خطافات الويب Webhooks متاحة الآن لتطبيق الروبوتات bot. لمزيد المعلومات، أنظر التوثيق في: https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- قم بتعيين تذكير على رسالة محادثة ليتم إشعارك بها لاحقًا ",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- استَخدِم محادثة **ملاحظة ذاتية Note to self** لتدوين الملاحظات ومشاركة المعلومات بين أجهزتك",
    "- Captions allow to send a message with a file at the same time" : "- تٌمكِّنُك التعليقات Captions من إلحاق رسالة بالملف المرسل في نفس الوقت",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- أصبح فيديو المُتحدِّث مرئيًا الآن أثناء مشاركة الشاشة و يتم كذلك تحريك تفاعلات المكالمات",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- يمكن الآن تعديل الرسائل من قِبَل المؤلفين و المشرفين إلى حد 6 ساعات",
    "- Unsent message drafts are now saved in your browser" : "- مسودات الرسائل غير المرسلة تبقى محفوظة على متصفحك للويب ",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- الدردشة النصية يمكن الآن إجراؤها عبر السحابة الاتحادية و خوادم تطبيق \"المحادثة\" Talk",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- يمكن للمشرفين الآن حظر حسابات أو ضيوف لمنعهم من الانضمام إلى محادثة",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- المكالمات الواردة من أحداث مربوطة على التقويم أو استبدالات لشخص خارج المكتب يمكن الآن عرضها في المحادثات",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- المكالمات يمكن الآن إجراؤها عبر السحابة الاتحادية و خوادم تطبيق \"المحادثة\" Talk (لكنها تستلزم توفير واجهة خلفية عالية الأداء HPB)",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- تقديم تطبيق نكست كلاود للمحادثة على سطح المكتب لنظم وندوز، و ماك، و لينكس: %s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- تلخيص تسجيلات المكالمات والرسائل غير المقروءة في الدردشات باستخدام \"مساعد\" نكست كلاود.",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- تحسين الاجتماعات من خلال التعرف على الضيوف المدعوين عبر عناوين بريدهم الإلكتروني، واستيراد قوائم المشاركين، ومسودات الاستطلاعات، وتنزيل قوائم المشاركين في المكالمات",
    "- Archive conversations to stay focused" : "- أرشفة المحادثات للمحافظة على التركيز",
    "- Schedule a meeting into your calendar from within a conversation" : "- جدولة اجتماع في تقويمك من داخل المحادثة",
    "- Search for messages of the current conversation directly in the right sidebar" : "- البحث عن رسائل المحادثة الحالية مباشرة في الشريط الجانبي الأيمن",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "- يمكنك رؤية المزيد من المحادثات بنظرة واحدة باستخدام القائمة المدمجة الجديدة (يمكنك تمكينها في إعدادات المحادثة)",
    "_All %n participant_::_All %n participants_" : ["كل الـ%n مشارك","كل الـ%n مشارك","كل الـ %n مشاركين","كل الـ%n مشاركين","كل الـ%n مشارك","كل الـ%n مشارك"],
    "Talk updates ✅" : "تحديثات التحدث  ✅",
    "Reaction deleted by author" : "تم حذف تفاعل من قبل الكاتب",
    "{actor} created the conversation" : "{actor} قام بإنشاء محادثة",
    "You created the conversation" : "أنشأتَ المحادثة",
    "System created the conversation" : "قام النظام بإنشاء هذه المحادثة تلقائياً",
    "An administrator created the conversation" : "المسؤول انشئ محادثة",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} اعاد تسمية المحادثة من \"%1$s\" إلى \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "قمت بإعادة تسمية المحادثة من \"%1$s\" إلى \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "قام المسؤول بإعادة تسمية المحادثة من \"%1$s\" إلى \"%2$s\"",
    "{actor} set the description" : "{actor} قام بتعيين الوصف ",
    "You set the description" : "قمت بتعيين الوصف ",
    "An administrator set the description" : "قام المسؤول بتعيين الوصف",
    "{actor} removed the description" : "{actor} قام بحذف الوصف ",
    "You removed the description" : "قمت بحذف الوصف ",
    "An administrator removed the description" : "قام المسؤول بحذف الوصف",
    "You started a silent call" : "لقد بَدَأتَ مكالمة صامتة",
    "Outgoing silent call" : "مكالمة صامتة صادرة",
    "{actor} started a silent call" : "{actor} بدأ مكالمة صامتة",
    "Incoming silent call" : "مكالمة صامتة واردة",
    "You started a call" : "أنت بدأت مكالمة",
    "Outgoing call" : "مكالمة صادرة",
    "{actor} started a call" : "{actor} بدأ مكالمة",
    "Incoming call" : "مكالمة واردة",
    "{actor} joined the call" : "{actor} انضم إلى المكالمة",
    "You joined the call" : "أنت انضممت للمكالمة",
    "{actor} left the call" : "{actor} غادر المكالمة",
    "You left the call" : "لقد قمت بمغادرة المكالمة",
    "{actor} unlocked the conversation" : "{actor} أزال قفل المحادثة",
    "You unlocked the conversation" : "أنت أزلت اقفال المكالمة",
    "An administrator unlocked the conversation" : "قامت الإدارة بإزالة قفل المحادثة ",
    "{actor} locked the conversation" : "{actor} اقفل المحادثة",
    "You locked the conversation" : "أنت اقفلت المحادثة",
    "An administrator locked the conversation" : " الإدارة اقفلت المحادثة",
    "{actor} limited the conversation to the current participants" : "{actor} قام بحد الرسائل للمشاركين الحاليين",
    "You limited the conversation to the current participants" : "قمت بحد الرسائل للمشاركين الحاليين",
    "An administrator limited the conversation to the current participants" : "قامت الإدارة بحد الرسائل للمشاركين الحاليين",
    "{actor} opened the conversation to registered users" : "{actor} اتاح المحادثة للمستخدمين المسجلين ",
    "You opened the conversation to registered users" : "قمت بإتاحة المحادثة للمستخدمين المسجلين ",
    "An administrator opened the conversation to registered users" : "قامت الإدارة بإتاحة المحادثة للمستخدمين المسجلين ",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} قام بفتح المحادثة للمستخدِمين المسجلين و المستخدِمين الذين تمّ استحداثهم عن طريق تطبيق الضيوف Gustes app",
    "You opened the conversation to registered users and users created with the Guests app" : "أنت قمت بفتح المحادثة للمستخدِمين المسجلين و المستخدِمين الذين تمّ استحداثهم عن طريق تطبيق الضيوف Gustes app",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "قام مدير بفتح المحادثة للمستخدِمين المسجلين و المستخدِمين الذين تمّ استحداثهم عن طريق تطبيق الضيوف Gustes app",
    "The conversation is now open to everyone" : "المحادثة الآن مفتوحة للجميع",
    "{actor} opened the conversation to everyone" : "{actor} اتاح المحادثة للجميع",
    "You opened the conversation to everyone" : "أنت سمحت بإتاحة المحادثة للجميع",
    "{actor} restricted the conversation to moderators" : "{actor} اقتصرت المحادثة على المشرفيين",
    "You restricted the conversation to moderators" : "أنت اقتصرت المحادثة على المشرفيين",
    "{actor} started breakout rooms" : "بدأ {actor} الغرف الجانبية",
    "You started breakout rooms" : "لقد بدأت الغرف الجانبية",
    "{actor} stopped breakout rooms" : "قام {actor} بوقف الغرف الجانبية",
    "You stopped breakout rooms" : "لقد قمت بوقف الغرف الجانبية",
    "{actor} allowed guests" : "{actor} السماح للضيوف بالانضمام",
    "You allowed guests" : "أنت وافقت على انضمام الضيوف",
    "An administrator allowed guests" : "الإدارة وافقت على انضمام الضيوف",
    "{actor} disallowed guests" : "{actor} منع الضيوف",
    "You disallowed guests" : "أنت منعت الضيوف",
    "An administrator disallowed guests" : "الإدارة منعت الضيوف",
    "{actor} set a password" : "{actor} تعيين كلمة مرور",
    "You set a password" : "أنت قمت بتعيين كلمة مرور",
    "An administrator set a password" : "تعيين كلمة مرور من قبل الإدارة",
    "{actor} removed the password" : "{actor} إلغاء كلمة المرور",
    "You removed the password" : "أنت حذفت كلمة المرور",
    "An administrator removed the password" : "الإدارة حذفت كلمة المرور",
    "{actor} added {user}" : "{actor} اضاف {user}",
    "You joined the conversation" : "انضممت للمحادثة",
    "{actor} joined the conversation" : "{actor} انضم للمحادثة",
    "You added {user}" : "أنت اضفت {user}",
    "{actor} added you" : "{actor} أضافك أنت",
    "An administrator added you" : "الإدارة قامت بإضافتك أنت",
    "An administrator added {user}" : "الإدارة أضافت {user}",
    "You left the conversation" : "لقد غادرت المحادثة",
    "{actor} left the conversation" : "{actor} غادر المحادثة",
    "{actor} removed {user}" : "{actor} حذف {user}",
    "You removed {user}" : "أنت قمت بحذف {user}",
    "{actor} removed you" : "{actor} قام بحذفك",
    "An administrator removed you" : "الإدارة قامت بحذفك",
    "An administrator removed {user}" : "الإدارة حذفت {user}",
    "{actor} invited {federated_user}" : "{actor} قام بدعوة {federated_user}",
    "You invited {federated_user}" : "أنت قمت بدعوة {federated_user}",
    "You accepted the invitation" : "أنت قَبَلت الدعوة",
    "{actor} invited you" : "{actor} قام بدعوتك",
    "An administrator invited you" : "قام مدير بدعوتك",
    "An administrator invited {federated_user}" : "قام مدير بدعوة {federated_user}",
    "{federated_user} accepted the invitation" : "قَبَل {federated_user} الدعوة",
    "{actor} removed {federated_user}" : "قام {actor} بإزالة {federated_user}",
    "You removed {federated_user}" : "لقد قمت بحذف {federated_user}",
    "You declined the invitation" : "أنت رفضت الدعوة",
    "An administrator removed {federated_user}" : "قام مدير بحذف {federated_user}",
    "{federated_user} declined the invitation" : "رفض {federated_user} الدعوة",
    "{actor} added group {group}" : "أضاف {actor} مجموعة {group}",
    "You added group {group}" : "لقد أضفت مجموعة {group}",
    "An administrator added group {group}" : "أضاف المسؤول مجموعة {group}",
    "{actor} removed group {group}" : "قام {actor} بإزالة مجموعة {group}",
    "You removed group {group}" : "لقد قمت بإزالة مجموعة {group}.",
    "An administrator removed group {group}" : "قام المسؤول بإزالة مجموعة {group}",
    "{actor} added team {circle}" : "قام {actor} بإضافة الفريق {circle}",
    "You added team {circle}" : "أنت قمت بإضافة الفريق {circle}",
    "An administrator added team {circle}" : "قام مدير بإضافة الفريق {circle}",
    "{actor} removed team {circle}" : "قام {actor} بحذف الفريق {circle}",
    "You removed team {circle}" : "أنت قمت بحذف الفريق {circle}",
    "An administrator removed team {circle}" : "قم مدير بحذف الفريق {circle}",
    "{actor} added {phone}" : "قام {actor} بإضافة {phone}",
    "You added {phone}" : "أنت قمت بإضافة {phone}",
    "An administrator added {phone}" : "قام مدير بإضافة {phone}",
    "{actor} removed {phone}" : "قام {actor} بحذف {phone}",
    "You removed {phone}" : "أنت قمت بحذف {phone}",
    "An administrator removed {phone}" : "قام مدير بحذف {phone}",
    "{actor} promoted {user} to moderator" : "تم ترقية {user} من قبل {actor}",
    "You promoted {user} to moderator" : "قمت بترقية {user} إلى مشرف",
    "{actor} promoted you to moderator" : "تم ترقيتك إلى مشرف من قبل {actor}",
    "An administrator promoted you to moderator" : "تم ترقيتك إلى مشرف من قبل الادارة",
    "An administrator promoted {user} to moderator" : "تم ترقية {user} من قبل الادارة",
    "{actor} demoted {user} from moderator" : "تم خفض رتبة الاشراف من {user} من قبل {actor}",
    "You demoted {user} from moderator" : "لقد خفضت رتبة الاشراف {user}",
    "{actor} demoted you from moderator" : "تم تخفيض رتب الاشراف من قبل {actor}",
    "An administrator demoted you from moderator" : "تم تخفيض رتبتك بالاشراف من قبل الادارة",
    "An administrator demoted {user} from moderator" : "تم تخفيض رتبة الاشراف من {user} من قبل الادارة",
    "{actor} shared a file which is no longer available" : "{actor} قام بمشاركة ملف لم يعد متاح",
    "You shared a file which is no longer available" : "قمت بمشاركة ملف لم يعد متاح",
    "File shares are currently not supported in federated conversations" : "مشاركة الملفات غير مدعومة حاليّاً في حالة المحادثات عبر السحابة الموحدة",
    "The shared location is malformed" : "الموقع المشترك غير صحيح",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "قام {actor} بإعداد Matterbridge لمزامنة هذه المحادثة مع الدردشات الأخرى.",
    "You set up Matterbridge to synchronize this conversation with other chats" : "قمت بإعداد Matterbridge لمزامنة هذه المحادثة مع الدردشات الأخرى.",
    "{actor} updated the Matterbridge configuration" : "قام {actor} بتحديث تكوين Matterbridge .",
    "You updated the Matterbridge configuration" : "لقد قمت بتحديث تكوين Matterbridge .",
    "{actor} removed the Matterbridge configuration" : "قام {actor} بإزالة تكوين Matterbridge .",
    "You removed the Matterbridge configuration" : "لقد قمت بإزالة تكوين Matterbridge .",
    "{actor} started Matterbridge" : " {actor} بدأ Matterbridge .",
    "You started Matterbridge" : "لقد بدأت Matterbridge .",
    "{actor} stopped Matterbridge" : "قام {actor} بإيقاف Matterbridge .",
    "You stopped Matterbridge" : "قمت بإيقاف Matterbridge .",
    "{actor} deleted a message" : "{actor} مسح رسالة ",
    "You deleted a message" : "أنت حذفت الرسالة ",
    "{actor} edited a message" : "{actor} قام بتحرير رسالة",
    "You edited a message" : "أنت قمت بتحرير رسالة",
    "{actor} deleted a reaction" : "حذف {actor} تفاعل",
    "You deleted a reaction" : "لقد قمت بحذف تفاعل",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["لقد قمت بتعيين انتهاء صلاحية الرسالة بعد%n أسابيع","لقد قمت بتعيين انتهاء صلاحية الرسالة بعد %nأسبوع","لقد قمت بتعيين انتهاء صلاحية الرسالة بعد %nأسابيع","لقد قمت بتعيين انتهاء صلاحية الرسالة بعد %n أسابيع","لقد قمت بتعيين انتهاء صلاحية الرسالة بعد %nأسابيع","لقد قمت بتعيين انتهاء صلاحية الرسالة بعد %nأسابيع"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["لقد قمت بتعيين انتهاء صلاحية الرسالة بعد %n أيام","لقد قمت بتعيين انتهاء صلاحية الرسالة بعد %n يوم","لقد قمت بتعيين انتهاء صلاحية الرسالة بعد %n أيام","لقد قمت بتعيين انتهاء صلاحية الرسالة بعد %n أيام","لقد قمت بتعيين انتهاء صلاحية الرسالة بعد %nأيام","لقد قمت بتعيين انتهاء صلاحية الرسالة بعد %n أيام"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["لقد قمت بتعيين انتهاء صلاحية الرسالة بعد %n ساعات","لقد قمت بتعيين انتهاء صلاحية الرسالة بعد %n ساعة","لقد قمت بتعيين انتهاء صلاحية الرسالة بعد %nساعات","لقد قمت بتعيين انتهاء صلاحية الرسالة بعد %nساعات","لقد قمت بتعيين انتهاء صلاحية الرسالة بعد %nساعات","لقد قمت بتعيين انتهاء صلاحية الرسالة بعد %nساعات"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["لقد قمت بتعيين انتهاء صلاحية الرسالة بعد %n دقائق","لقد قمت بتعيين انتهاء صلاحية الرسالة بعد %n دقيقة","لقد قمت بتعيين انتهاء صلاحية الرسالة بعد %n دقائق","لقد قمت بتعيين انتهاء صلاحية الرسالة بعد %n دقائق","لقد قمت بتعيين انتهاء صلاحية الرسالة بعد %n دقائق","لقد قمت بتعيين انتهاء صلاحية الرسالة بعد %n دقائق"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["قام {actor} بتعيين انتهاء صلاحية الرسالة بعد %nأسابيع","قام {actor} بتعيين انتهاء صلاحية الرسالة بعد %n أسبوع","قام {actor} بتعيين انتهاء صلاحية الرسالة بعد %n أسابيع","قام {actor} بتعيين انتهاء صلاحية الرسالة بعد %n أسابيع","قام {actor} بتعيين انتهاء صلاحية الرسالة بعد %n أسابيع","قام {actor} بتعيين انتهاء صلاحية الرسالة بعد %n أسابيع"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["قام {actor} بتعيين انتهاء صلاحية الرسالة بعد %n أيام","قام {actor} بتعيين انتهاء صلاحية الرسالة بعد %n يوم","قام {actor} بتعيين انتهاء صلاحية الرسالة بعد %n أيام","قام {actor} بتعيين انتهاء صلاحية الرسالة بعد %n أيام","قام {actor} بتعيين انتهاء صلاحية الرسالة بعد %n أيام","قام {actor} بتعيين انتهاء صلاحية الرسالة بعد %n أيام"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["قام {actor} بتعيين انتهاء صلاحية الرسالة بعد %n ساعات","قام {actor} بتعيين انتهاء صلاحية الرسالة بعد  %nساعة","قام {actor} بتعيين انتهاء صلاحية الرسالة بعد %n ساعات","قام {actor} بتعيين انتهاء صلاحية الرسالة بعد %nساعات","قام {actor} بتعيين انتهاء صلاحية الرسالة بعد %n ساعات","قام {actor} بتعيين انتهاء صلاحية الرسالة بعد %nساعات"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["قام {actor} بتعيين انتهاء صلاحية الرسالة بعد %n دقائق","قام {actor} بتعيين انتهاء صلاحية الرسالة بعد %n دقيقة","قام {actor} بتعيين انتهاء صلاحية الرسالة بعد %n دقائق","قام {actor} بتعيين انتهاء صلاحية الرسالة بعد %n دقائق","قام {actor} بتعيين انتهاء صلاحية الرسالة بعد %n دقائق","قام {actor} بتعيين انتهاء صلاحية الرسالة بعد %n دقائق"],
    "{actor} disabled message expiration" : "قام {actor} بتعطيل تعيين انتهاء صلاحية الرسالة ",
    "You disabled message expiration" : "لقد قمت بتعطيل تعيين انتهاء صلاحية الرسالة",
    "{actor} cleared the history of the conversation" : "قام {actor} بمسح تاريخ المحادثة",
    "You cleared the history of the conversation" : "لقد قمت بمسح تاريخ المحادثة",
    "{actor} set the conversation picture" : "{actor} عيّن صورةً للمحادثة ",
    "You set the conversation picture" : "أنت عيّنت صورةً للمحادثة",
    "{actor} removed the conversation picture" : "{actor} حذف صورة المحادثة",
    "You removed the conversation picture" : "أنت حذفت صورة المحادثة",
    "{actor} ended the poll {poll}" : "قام {actor} بإنهاء استطلاع {poll}",
    "You ended the poll {poll}" : "لقد قمت بإنهاء استطلاع {poll}",
    "{actor} started the video recording" : "قام {actor} ببدء تسجيل فيديو",
    "You started the video recording" : "لقد بدأت تسجيل فيديو",
    "{actor} stopped the video recording" : "قام {actor} بإيقاف تسجيل الفيديو",
    "You stopped the video recording" : "لقد قمت بإيقاف تسجيل الفيديو",
    "{actor} started the audio recording" : "قام {actor} ببدء تسجيل صوتي",
    "You started the audio recording" : "لقد قمت ببدء تسجيل الصوتي",
    "{actor} stopped the audio recording" : "قام {actor} بإيقاف التسجيل الصوتي",
    "You stopped the audio recording" : "لقد قمت بإيقاف التسجيل الصوتي",
    "The recording failed" : "فشل في التسجيل",
    "Someone voted on the poll {poll}" : "قامل شخص بالتصويت في استطلاع {poll}",
    "Message deleted by author" : "مٌسحت الرسالة بواسطة الكاتب ",
    "Message deleted by {actor}" : "مُسحت الرسالة بواسطة {actor}",
    "Message deleted by you" : "مُسحت الرسالة بواسطتك",
    "Deleted user" : "مستخدم محذوف",
    "Unknown number" : "رقم غير معروف",
    "Administration" : "الإدارة",
    "System" : "النظام",
    "%s (guest)" : "%s (ضيف)",
    "Missed call" : "مكالمة فائتة",
    "Unanswered call" : "مكالمة فائتة",
    "Call ended (Duration {duration})" : "انتهت المكالمة (المدة {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "تم إنهاء المكالمة، حيث وصلت إلى الحد الأقصى لمدة المكالمة (المدة {duration})",
    "{actor} ended the call (Duration {duration})" : "أنهى {actor} المكالمة (المدة {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["إنتهت للتوّ مكالمة فيها %n ضيف بسبب تجاوز الحدّ الأقصى لمدة المكالمة (المدة {duration} )","إنتهت للتوّ مكالمة فيها %n ضيف بسبب تجاوز الحدّ الأقصى لمدة المكالمة (المدة {duration})","إنتهت للتوّ مكالمة فيها %n ضيف بسبب تجاوز الحدّ الأقصى لمدة المكالمة (المدة {duration})","إنتهت للتوّ مكالمة فيها %n ضيف بسبب تجاوز الحدّ الأقصى لمدة المكالمة (المدة {duration})","إنتهت للتوّ مكالمة فيها %n ضيف بسبب تجاوز الحدّ الأقصى لمدة المكالمة (المدة {duration})","إنتهت للتوّ مكالمة فيها %n ضيف بسبب تجاوز الحدّ الأقصى لمدة المكالمة (المدة {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["المكالمة التي فيها %n ضيف انتهت (المدة {duration})","المكالمة التي فيها %n ضيف انتهت (المدة {duration})","المكالمة التي فيها %n ضيف انتهت (المدة{duration})","المكالمة التي فيها %n ضيوف انتهت (المدة {duration})","المكالمة التي فيها %n ضيف انتهت (المدة {duration})","المكالمة التي فيها %n ضيف انتهت (المدة{duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["قام {actor} بإنهاء المكالمة مع %n من الضيوف (المدة {duration})","قام {actor} بإنهاء المكالمة مع %n ضيف (المدة {duration})","قام {actor} بإنهاء المكالمة مع %n من الضيوف (المدة {duration})","قام {actor} بإنهاء المكالمة مع  %nمن الضيوف (المدة {duration})","قام {actor} بإنهاء المكالمة مع %nمن الضيوف (المدة {duration})","قام {actor} بإنهاء المكالمة مع %n من الضيوف (المدة {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "المكالمة مع {user1} تمّ إنهاؤها بسبب تجاوزها الحدّ الأقصى لمدة المكالمات ( المدة{duration})",
    "Call with {user1} ended (Duration {duration})" : "المكالمة مع {user1} تمّ إنهاؤها (المدة {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "قام {actor} بإنهاء المكالمة مع {user1} (المدة {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "المكالمة مع {user1} و {user2} تمّ إنهاؤها بسبب تجاوز الحدّ الأقصى لمدة المكالمات (المدة {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "مكالمة {user1}، و {user2} انتهت (المدة {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "قام {actor} بإنهاء المكالمة مع {user1} و {user2} (المدة {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "المكالمة مع {user1}،و {user2} ،و {user3} تمّ إنهاؤها بسبب تجاوز الحد الأقصى لمدة المكالمات (المدة {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "مكالمة {user1}، و {user2}، و {user3} انتهت (المدة {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "قام {actor} بإنهاء المكالمة مع {user1} و {user2} و {user3} (المدة {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "المكالمة مع {user1},و {user2}, و{user3} ،و {user4} تمّ إنهاؤها بسبب تجاوز الحد الأقصى لمدة المكالمات (المدة {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "مكالمة {user1}، و {user2}، و {user3}، و {user4} انتهت (المدة {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "قام {actor} بإنهاء المكالمة مع {user1} و {user2} و {user3} و {user4} (المدة {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "المكالمة مع {user1}, و{user2},و {user3},و {user4} ،و {user5}  تمّ إنهاؤها بسبب تجاوز الحد الأقصى لمدة المكالمات (المدة {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "مكالمة {user1}، و {user2}، و {user3}، و {user4}، و {user5} انتهت (المدة {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "قام {actor} بإنهاء المكالمة مع {user1} و {user2} و {user3} و {user4} و {user5} (المدة {duration})",
    "Message of {user} in {conversation}" : "رسالة من {user} في {conversation}",
    "Message of {user}" : "رسالة من {user}",
    "Message of a deleted user in {conversation}" : "رسالة من مستخدِم محذوف في {conversation}",
    "Talk conversations" : "محادثات",
    "Call %s" : "إتصل بـ%s",
    "An error occurred. Please contact your administrator." : "حدث خطأٌ. يرجى الاتصال بمسؤول النظام.",
    "Storage quota exceeded" : "الحصة التخزينية تمّ استنفاذها",
    "File not found" : "تعذر العثور على الملف",
    "File is not shared, or shared but not with the user" : "الملف لم يتم مشاركته أو ليس مع المستخدم صلاحية للإطلاع على الملف",
    "No account available to delete." : "لا يوجد حساب متاح للحذف",
    "Poll" : "استبيان",
    "Password needs to be set" : "يجب تعيين كلمة المرور",
    "Uploading the file failed" : "فشل تحميل الملف",
    "No image file provided" : "لم يتم توفير صورة ملف",
    "File is too big" : "الملف كبير جدًا",
    "Invalid file provided" : "تم تقديم ملف غير صالح",
    "Invalid image" : "الصورة غير صالحة",
    "Unknown filetype" : "نوع الملف غير معروف",
    "Talk mentions" : "إشارات في المحادثات",
    "More conversations" : "محادثات أخرى",
    "Say hi to your friends and colleagues!" : "قل مرحبا ً لزملاء العمل!",
    "No unread mentions" : "لا توجد إشارة جديدة لك",
    "Call in progress" : "محادثة جارية",
    "You were mentioned" : "منشن بإسمك",
    "Write to conversation" : "اكتب للمحادثة",
    "Writes event information into a conversation of your choice" : "اكتب معلومات الحدث في محادثة من اختيارك",
    "Missing email field in header line" : "خانة البريد الإلكتروني في سطر الترويسة ناقصة",
    "Following lines are invalid: %s" : "السطر التالي غير صحيح %s",
    "Conversation invitation" : "دعوة محادثة",
    "Description" : "الوصف",
    "You can also dial-in via phone with the following details" : "يمكنك أيضًا الاتصال عبر الهاتف بالتفاصيل التالية",
    "Dial-in information" : "معلومات الإتصال",
    "Meeting ID" : "معرف الإجتماع ",
    "Your PIN" : "رقمك السري",
    "Meeting" : "اجتماع",
    "Password request: %s" : "طلب كلمة المرور: %s",
    "Private conversation" : "محادثة خاصة",
    "Deleted user (%s)" : "تم حذف العضو (%s)",
    "Failed to upload call recording" : "تعذّر رفع تسجيل المكالمة",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "خادم التسجل فشل في رفع تسجيل المكالمة  {call}. يرجى التواصل مع مسؤول النظام.",
    "Share to chat" : "شارك بالدردشة",
    "Dismiss notification" : "تجاهل الإشعار",
    "Call recording now available" : "تسجيل المكالمة متاحٌ الآن",
    "The recording for the call in {call} was uploaded to {file}." : "تسجيل المكالمة في  {call} تمّ رفعه إلى {file}.",
    "Transcript now available" : "التحويل من كلام إلى نصٍ متاحٌ الآن",
    "The transcript for the call in {call} was uploaded to {file}." : "نص المكالمة  {call} تمّ رفعه بعد تحويله إلى {file}.",
    "Failed to transcript call recording" : "تعذّر تحويل تسجيل المكالمة إلى نص",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "فشل الخادم في تحويل تسجيل المكالمة في {file} للمكالمة {call} إلى نص. يرجى التواصل مع مسؤول النظام.",
    "Call summary now available" : "ملخص المكالمة جاهزٌ الآن",
    "The summary for the call in {call} was uploaded to {file}." : "ملخص المكالمة في {call} تمّ تحميله إلى {file}.",
    "Failed to summarize call recording" : "تعذّر تلخيص تسجيل المكالمة",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "أخفق الخادوم في تلخيص التسجيل عند {file} للمكالمة في {call}.  رجاءً، تواصل مع مشرف النظام.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} دعاك للانضمام إلى غرفة: {roomName} على الخادوم: {remoteServer}",
    "Accept" : "قبول",
    "Decline" : "رفض",
    "{user1} invited you to a federated conversation" : "{user1} دعاك للانضمام إلى مُحادثة على سحابة اتحاديّة",
    "New message" : "رسالة جديدة",
    "Reminder" : "تذكير",
    "Notification" : "إشعار",
    "Reminder: You in {call}" : "تذكير: أنت في {call}",
    "Reminder: {user} in {call}" : "تذكير: {user} في {call}",
    "Reminder: Deleted user in {call}" : "تذكير: مستخدِم محذوف في {call}",
    "Reminder: {guest} (guest) in {call}" : "تذكير: {guest} (ضيف) في {call}",
    "Reminder: Guest in {call}" : "تذكير: ضيف في {call}",
    "{user} reacted with {reaction}" : "{user} تَفَاعَلَ بـ {reaction}",
    "{user} reacted with {reaction} in {call}" : "{user} تَفَاعَلَ بـ {reaction} في {call}",
    "Deleted user reacted with {reaction} in {call}" : "مستخدِم محذوف تَفَاعَلَ بـ {reaction} في {call}",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (ضيف) تَفَاعَلَ بـ {reaction} في {call}",
    "Guest reacted with {reaction} in {call}" : "تَفَاعَلَ ضيفُ بـ {reaction} في {call}",
    "{user} in {call}" : "{user} في {call}",
    "Deleted user in {call}" : "تم حذف العضو في {call}",
    "{guest} (guest) in {call}" : "{guest} (ضيف) في {call}",
    "Guest in {call}" : "ضيف في {call}",
    "{user} sent you a private message" : "{user} ارسل لك رسالة خاصة",
    "{user} sent a message in conversation {call}" : "{user} ارسل رسالة في المحادثة {call}",
    "A deleted user sent a message in conversation {call}" : "عضو محذوف قام بإرسال رسالة في محادثة {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (ضيف) ارسل رسالة لمحادثة {call}",
    "A guest sent a message in conversation {call}" : "ضيف ارسل رسالة للمحادثة {call}",
    "{user} replied to your private message" : "{user} قام بالرد على رسالتك الخاصة",
    "{user} replied to your message in conversation {call}" : "{user} قام بالرد على رسالتك في محادثة {call}",
    "A deleted user replied to your message in conversation {call}" : "عضو محذوف رد على رسالتك في محادثة {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (ضيف) قام بالرد على رسالتك في محادثة {call}",
    "A guest replied to your message in conversation {call}" : "ضيف قام بالرد على رسالتك في محادثة {call}",
    "Reminder: You in private conversation {call}" : "تذكير: أنت في محادثة خاصة {call}",
    "Reminder: A deleted user in private conversation {call}" : "تذكير: مستخدِم محذوف في محادثة خاصة {call}",
    "Reminder: {user} in private conversation" : "تذكير: {user} في محادثة خاصة",
    "Reminder: You in conversation {call}" : "تذكير: أنت في محادثة {call}",
    "Reminder: {user} in conversation {call}" : "تذكير: {user} في محادثة {call}",
    "Reminder: A deleted user in conversation {call}" : "تذكير: مستخدِم محذوف في محادثة {call}",
    "Reminder: {guest} (guest) in conversation {call}" : "تذكير: {guest} (ضيف) في محادثة {call}",
    "Reminder: A guest in conversation {call}" : "تذكير: ضيف في محادثة {call}",
    "{user} reacted with {reaction} to your private message" : "تفاعل {user} بـ {reaction} على رسالتك الخاصة",
    "{user} reacted with {reaction} to your message in conversation {call}" : "تفاعل {user} بـ {reaction} على رسالتك في المحادثة {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "تفاعل مستخدم محذوف بـ {reaction} على رسالتك في المحادثة {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "رد (ضيف){guest} بـ {reaction} على رسالتك في المحادثة {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "رد ضيف بـ {reaction} على رسالتك في المحادثة {call}",
    "{user} mentioned you in a private conversation" : "{user} مشار له في رسالة خاصة",
    "{user} mentioned group {group} in conversation {call}" : "{user} أشار إلى المجموعة {group} iفي المحادثة {call}",
    "{user} mentioned team {team} in conversation {call}" : "{user} أشار للفريق {team} في المحادثة {call}",
    "{user} mentioned everyone in conversation {call}" : "{user} أشار إلى الجميع في المحادثة {call}",
    "{user} mentioned you in conversation {call}" : "{user} مشار له في محادثة {call}",
    "A deleted user mentioned group {group} in conversation {call}" : "مستخدِمٌ محذوفٌ أشار إلى المجموعة {group} في المحادثة {call}.",
    "A deleted user mentioned team {team} in conversation {call}" : "مُستخدِم محذوف أشار للفريق {team} في المحادثة {call}",
    "A deleted user mentioned everyone in conversation {call}" : "مستخدِمٌ محذوفٌ أشار إلى الجميع في المحادثة {call}.",
    "A deleted user mentioned you in conversation {call}" : "عضو محذوف أشار لاسمك في محادثة {call}",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (guest) أشار إلى المجموعة {group} في المحادثة {call}",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "{guest} (الضيف) أشار للفريق {team} في المحادثة {call}",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (guest) أشار إلى الجميع في المحادثة {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (ضيف) أشار لاسمك في محادثة {call}",
    "A guest mentioned group {group} in conversation {call}" : "ضيفٌ أشار إلى المجموعة {group} في المحادثة {call}",
    "A guest mentioned team {team} in conversation {call}" : "أشار ضيف للفريق {team} في المحادثة {call}",
    "A guest mentioned everyone in conversation {call}" : "ضيفٌ أشار إلى الجميع في المحادثة {call}",
    "A guest mentioned you in conversation {call}" : "ضيف أشار لاسمك في محادثة {call}",
    "View message" : "إعرِض الرسالة",
    "Dismiss reminder" : "تجاهل التذكير",
    "View chat" : "عرض المحادثة",
    "{user} invited you to a group conversation: {call}" : "{user} قام بدعوتك للإنضمام لمحادثة جماعية: {call}",
    "Join call" : "انضمام لمكالمة",
    "Answer call" : "الرد على المكالمة",
    "{user} would like to talk with you" : "{user} يريد التحدث إليك",
    "Call back" : "معاودة الاتصال",
    "You missed a call from {user}" : "مكالمة لم ترد عليها من {user}",
    "A group call has started in {call}" : "اتصال جماعي بدأ في {call}",
    "You missed a group call in {call}" : "اتصال جماعي لم ترد عليه في {call}",
    "{email} is requesting the password to access {file}" : "{email} انشأ طلب كلمة المرور للوصول إلى الملف {file}",
    "{email} tried to request the password to access {file}" : "{email} حاول طلب كلمة المرور للوصول للملف {file}",
    "Someone is requesting the password to access {file}" : "شخص انشأ طلب كلمة المرور للوصول للملف {file}",
    "Someone tried to request the password to access {file}" : "شخص حاول طلب كلمة المرور للوصول للملف {file}",
    "Open settings" : "فتح الإعدادات",
    "Hosted signaling server added" : "تمّت إضافة خادوم إشارة مُستضاف Hosted signaling server",
    "The hosted signaling server is now configured and will be used." : "تم تكوين خادم التشوير المستضاف الآن وسيتم استخدامه.",
    "Hosted signaling server removed" : "تمّ حذف خادوم إشارة مُستضاف Hosted signaling server",
    "The hosted signaling server was removed and will not be used anymore." : "تمت إزالة خادم التشوير المستضاف ولن يتم استخدامه بعد الآن.",
    "Hosted signaling server changed" : "تمّ تغيير خادوم إشارة مُستضاف Hosted signaling server",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "قام حساب خادم التشوير المستضاف بتغيير الحالة من \"{oldstatus}\" إلى \"{newstatus}\".",
    "pending" : "مُعلّق قيد الانتظار",
    "active" : "نَشِطٌ",
    "expired" : "منتهي الصلاحية",
    "blocked" : "محظور",
    "error" : "خطأ",
    "The certificate of {host} expires in {days} days" : "تنتهي صلاحية شهادة {host} خلال {days} أيام",
    "The certificate of {host} expired" : "انتهت صلاحية شهادة {host}",
    "Contact via Talk" : "تواصل عبر تطبيق المحادثة",
    "Open Talk" : "تطبيق مؤتمرات الفيديو OpenTalk ",
    "Default" : "افتراضي",
    "Presentation" : "عرض تقديمي",
    "Webinar" : "نقاش عبر الويب - ويب نير",
    "Conversations" : "المحادثات",
    "Messages in current conversation" : "رسائل في المحادثة الحالية",
    "{user}" : "{user}",
    "Messages" : "الرسائل",
    "{user} in {conversation}" : "{user} في {conversation}",
    "Messages in other conversations" : "الرسائل في المحادثات الآخرى",
    "One-to-one rooms always need to show the other users avatar" : "غرف واحد لواحد يلزم فيها دائماً إظهار صورة الملف الشخصي الرمزية للأشخاص الآخرين",
    "Invalid emoji character" : "حرف إيموجي غير صحيح",
    "Invalid background color" : "لون خلفية غير صحيح",
    "Avatar image is not square" : "الصورة الرمزية ليست على شكل مربّع",
    "Room {number}" : "الغرفة {number}",
    "Favorites" : "المُفضّلة",
    "Other" : "آخر",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "فشل طلب التجربة لأن لا يمكن الوصول لخادم الإصدار التجريبي. يرجى معاودة المحاولة لاحقًا.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "هناك مشكلة في مصادقة هذه الحالة. ربما لا يمكن الوصول إليه من الخارج للتحقق من عنوان URL الخاص به.",
    "Something unexpected happened." : "حصل خطأ غير متوقع. ",
    "The URL is invalid." : "الرابط غير صحيح",
    "An HTTPS URL is required." : "مطلوب عنوان HTTPS URL.",
    "The email address is invalid." : "البريد الإلكتروني غير صحيح",
    "The language is invalid." : "اللغة غير صحيحة",
    "The country is invalid." : "الدولة غير صحيحة",
    "There is a problem with the request of the trial. Please check your logs for further information." : "حدثت مشكلة عند طلب التجربة. يرجى التحقق من سجلاتك للحصول على مزيد من المعلومات.",
    "Too many requests are send from your servers address. Please try again later." : "طلبات متعددة تم ارساله من عنوان خادمك. يرجى المحاولة لاحقا.",
    "There is already a trial registered for this Nextcloud instance." : "توجد بالفعل نسخة تجريبية مسجلة لمثيل نكست كلاود هذا.",
    "Something unexpected happened. Please try again later." : "حصل امر غير معتاد. يرجى إعادة المحاولة لاحقًا.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "فشل طلب التجربة لأن حدث خطأ بخادم الإصدار التجريبي. يرجى معاودة المحاولة لاحقًا.",
    "Trial requested but failed to get account information. Please check back later." : "تم طلب التجربة لكن فشل في الحصول على معلومات الحساب. يرجى التحقق مره أخرى لاحقًا. ",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "هناك مشكلة في مصادقة هذا الطلب. ربما لا يمكن الوصول إليه من الخارج للتحقق من عنوان URL الخاص به.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "فشل جلب معلومات الحساب لأن حدث خطأ بخادم الإصدار التجريبي. يرجى معاودة المحاولة لاحقًا.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "حدثت مشكلة عند جلب معلومات الحساب. يرجى التحقق من السجلات الخاصة بك للحصول على مزيد من المعلومات.",
    "There is no such account registered." : "الحساب غير مسجل",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "فشل جلب معلومات الحساب لأن لا يمكن الوصول لخادم الإصدار التجريبي. يرجى معاودة المحاولة لاحقًا.",
    "Deleting the hosted signaling server account failed. Please check back later." : "فشل حذف حساب خادم التشوير المستضاف. يرجى معاودة المحاولة لاحقًا.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "فشل حذف الحساب لأن حدث خطأ بخادم الإصدار التجريبي. يرجى معاودة المحاولة لاحقًا.",
    "There is a problem with deleting the account. Please check your logs for further information." : "حدثت مشكلة عند حذف الحساب. يرجى التحقق من السجلات الخاصة بك للحصول على مزيد من المعلومات.",
    "Too many requests are sent from your servers address. Please try again later." : "تم ارسال طلبات متعددة من عنوان خادمك. يرجى المحاولة لاحقًا.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "فشل حذف الحساب لأن لا يمكن الوصول لخادم الإصدار التجريبي. يرجى معاودة المحاولة لاحقًا.",
    "Note to self" : "ملاحظة شخصية",
    "A place for your private notes, thoughts and ideas" : "مكان لتسجيل ملاحظاتك و خططك و أفكارك",
    "Transcript is AI generated and may contain mistakes" : "النص تمّ توليده بواسطة الذكاء الاصطناعي؛ لذا يُحتمل أنه يحتوي على أخطاء",
    "Summary is AI generated and may contain mistakes" : "الملخص تمّ توليده بواسطة الذكاء الاصطناعي؛ لذا يُحتمل أنه يحتوي على أخطاء",
    "Let's get started!" : "فَلْنَبْدَإ الآن!",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "تطبيق \"المحادثة\" من نكست كلاود **Nextcloud Talk** هو عبارة عن منصة اتصال آمنة ذاتية الاستضافة تتكامل بسلاسة مع بيئة نكست كلاود. \n\n#### الميزات الرئيسية: \n* الدردشة والمراسلة في الدردشات الخاصة والجماعية \n* مكالمات صوتية وفيديو \n* مشاركة الملفات والتكامل مع تطبيقات نكست كلاود الأخرى \n* إعدادات محادثة قابلة للتخصيص، والتحكم في الخصوصية، والتنسيق \n* الويب وسطح المكتب والهاتف النقال (iOS وAndroid) \n* اتصالات خاصة وآمنة \n\nتعرف على المزيد في [وثائق المُستخدِم](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html).",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# مرحبًا بك في تطبيق \"المحادثة\" من نكست كلاود Nextcloud Talk \n\nهذا التطبيق هو تطبيق مراسلة خاص وقوي يتكامل مع بيئة نكست كلاود. \nيمكنك الدردشة في محادثات خاصة أو جماعية والتعاون عبر مكالمات الصوت والفيديو وتنظيم الندوات عبر الإنترنت واللقاءات وتخصيص محادثاتك؛ والمزيد المزيد.",
    "## 🎨 Format texts to create rich messages\n\nIn Nextcloud Talk, you can use Markdown syntax to format your messages. For example, apply **bold** or *italic* formatting, or `highlight texts as code`. You can even create tables and add headings to your text.\n\nNeed to fix a typo or change formatting? Edit your message by clicking \"Edit message\" in the message menu." : "## 🎨 تنسيق النصوص لإنشاء رسائل غنية \n\nفي تطبيق \"المحادثة\" من نكست كلاود Nextcloud Talk يمكنك استخدام صيغة Markdown لتنسيق رسائلك. على سبيل المثال، يمكنك تطبيق التنسيق **الغامق** أو *المائل*، أو \"تمييز النصوص ككود برمجي\". يمكنك أيضاً إنشاء جداول وإضافة عناوين إلى نصِّك. \n\nهل تحتاج إلى تصحيح خطأ مطبعي أو تغيير التنسيق؟ عدّل رسالتك بكل بساطة بالنقر فوق \"تعديل الرسالة\" في قائمة الرسائل.",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗 أضِف المُرفقات والروابط \n\nيمكنك إرفاق الملفات من نكست كلاود هَبْ  Hub باستعمال الزر \"+\". شارك العناصر من الملفات وتطبيقات نكست كلاود المتنوعة. تدعم بعض التطبيقات أيضاً عناصر واجهة المستخدم التفاعلية، على سبيل المثال، تطبيق \"الكتابة\" Text.",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "يمكنك الرّد على الرسائل أو إعادة توجيهها إلى دردشات أو أشخاص آخرين أو نسخ محتوى الرسالة.",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : "## ✨ افعل المزيد باستخدام \"اللاقط الذكي\" Smart Picker \n\nما عليك سوى كتابة \"/\" أو الانتقال إلى قائمة \"+\" لفتح \"اللاقط الذكي\"؛ حيث يمكنك إرفاق محتوىً متنوع مع رسائلك. يمكنك تهيئة اللاقط الذكي لتتمكن من إضافة عناصر من تطبيقات نكست كلاود وصور GIF ومواقع الخرائط والمحتوى الذي تم إنشاؤه بواسطة الذكاء الاصطناعي وغير ذلك كثير.",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## ⚙️ إدارة إعدادات المحادثة \n\nفي قائمة المحادثة، يمكنك الوصول إلى إعدادات مختلفة لإدارة محادثاتك، مثل: \n* تحرير معلومات المحادثة \n* إدارة الإشعارات \n* تطبيق قواعد تعديل متعددة \n* إعدادات حق الوصول والأمان \n* تمكين روبوتات الردود الآلية bot\n* والمزيد!",
    "Andorra" : "أندورا",
    "United Arab Emirates" : "الإمارات العربية المتحدة",
    "Afghanistan" : "أفغانستان",
    "Antigua and Barbuda" : "أنتيغوا وبربودا",
    "Anguilla" : "أنغيلا",
    "Albania" : "ألبانيا",
    "Armenia" : "أرمينيا",
    "Angola" : "أنغولا",
    "Antarctica" : "القارة القطبية الجنوبية",
    "Argentina" : "الأرجنتين",
    "American Samoa" : "ساموا الأمريكية",
    "Austria" : "النمسا",
    "Australia" : "أستراليا",
    "Aruba" : "أروبا",
    "Åland Islands" : "جزر آلاند",
    "Azerbaijan" : "أذربيجان",
    "Bosnia and Herzegovina" : "البوسنة والهرسك",
    "Barbados" : "بربادوس",
    "Bangladesh" : "بنغلاديش",
    "Belgium" : "بلجيكا",
    "Burkina Faso" : "بوركينا فاسو",
    "Bulgaria" : "بلغاريا",
    "Bahrain" : "البحرين",
    "Burundi" : "بوروندي",
    "Benin" : "البنين",
    "Saint Barthélemy" : "سانت بارتيليمي",
    "Bermuda" : "برمودا",
    "Brunei Darussalam" : "بروناي دار السلام",
    "Bolivia, Plurinational State of" : "بوليفيا المتعددة القوميات",
    "Bonaire, Sint Eustatius and Saba" : "بونير وسانت أوستاتيوس وسابا",
    "Brazil" : "البرازيل",
    "Bahamas" : "جزر البهاما",
    "Bhutan" : "بوتان",
    "Bouvet Island" : "جزيرة بوفيت",
    "Botswana" : "بوتسوانا",
    "Belarus" : "بيلاروسيا",
    "Belize" : "بليز",
    "Canada" : "كندا",
    "Cocos (Keeling) Islands" : "جزر كوكوس (كيلينغ)",
    "Congo, the Democratic Republic of the" : "جمهورية الكونغو الديمقراطية",
    "Central African Republic" : "جمهورية افريقيا الوسطى",
    "Congo" : "الكونغو",
    "Switzerland" : "سويسرا",
    "Côte d'Ivoire" : "ساحل العاج",
    "Cook Islands" : "جزر كوك",
    "Chile" : "تشيلي",
    "Cameroon" : "الكاميرون",
    "China" : "الصين",
    "Colombia" : "كولومبيا",
    "Costa Rica" : "كوستاريكا",
    "Cuba" : "كوبا",
    "Cabo Verde" : "كابو فيردي",
    "Curaçao" : "كوراساو",
    "Christmas Island" : "جزيرة الكريسماس",
    "Cyprus" : "قبرص",
    "Czechia" : "التشيك",
    "Germany" : "ألمانيا",
    "Djibouti" : "جيبوتي",
    "Denmark" : "الدانمارك",
    "Dominica" : "دومينيكا",
    "Dominican Republic" : "جمهورية الدومينيكان",
    "Algeria" : "الجزائر",
    "Ecuador" : "الاكوادور",
    "Estonia" : "إستونيا",
    "Egypt" : "مصر",
    "Western Sahara" : "الصحراء الغربية",
    "Eritrea" : "إريتريا",
    "Spain" : "إسبانيا",
    "Ethiopia" : "إثيوبيا",
    "Finland" : "فنلندا",
    "Fiji" : "فيجي",
    "Falkland Islands (Malvinas)" : "جزر فوكلاند (مالفيناس)",
    "Micronesia, Federated States of" : "ولايات ميكرونيسيا المتحدة",
    "Faroe Islands" : "جزر فاروس",
    "France" : "فرنسا",
    "Gabon" : "الغابون",
    "United Kingdom of Great Britain and Northern Ireland" : "المملكة المتحدة لبريطانيا العظمى وأيرلندا الشمالية",
    "Grenada" : "غرينادا",
    "Georgia" : "جيورجيا",
    "French Guiana" : "غيانا الفرنسية",
    "Guernsey" : "غيرنزي",
    "Ghana" : "غانا",
    "Gibraltar" : "جبل طارق",
    "Greenland" : "جرينلاند",
    "Gambia" : "غامبيا",
    "Guinea" : "غينيا",
    "Guadeloupe" : "غوادلوب",
    "Equatorial Guinea" : "غينيا الإستوائية",
    "Greece" : "اليونان",
    "South Georgia and the South Sandwich Islands" : "جورجيا الجنوبية وجزر ساندويتش الجنوبية",
    "Guatemala" : "غواتيمالا",
    "Guam" : "غوام",
    "Guinea-Bissau" : "غينيا بيساو",
    "Guyana" : "غيانا",
    "Hong Kong" : "هونج كونج",
    "Heard Island and McDonald Islands" : "قلب الجزيرة وجزر ماكدونالز",
    "Honduras" : "هندوراس",
    "Croatia" : "كرواتيا",
    "Haiti" : "هايتي",
    "Hungary" : "هنغاريا",
    "Indonesia" : "أندونيسيا",
    "Ireland" : "أيرلندا",
    "Israel" : "الكيان الصهيوني",
    "Isle of Man" : "جزيرة مان",
    "India" : "الهند",
    "British Indian Ocean Territory" : "إقليم المحيط البريطاني الهندي",
    "Iraq" : "العراق",
    "Iran, Islamic Republic of" : "إيران",
    "Iceland" : "ايسلندا",
    "Italy" : "إيطاليا",
    "Jersey" : "جيرسي",
    "Jamaica" : "جامايكا",
    "Jordan" : "الأردن",
    "Japan" : "اليابان",
    "Kenya" : "كينيا",
    "Kyrgyzstan" : "قيرغيزستان",
    "Cambodia" : "كمبوديا",
    "Kiribati" : "كيريباتي",
    "Comoros" : "جزر القمر",
    "Saint Kitts and Nevis" : "سانت كيتس ونيفيس",
    "Korea, Democratic People's Republic of" : " جمهورية كوريا الشعبية الديمقراطية",
    "Korea, Republic of" : "جمهورية كوريا",
    "Kuwait" : "الكويت",
    "Cayman Islands" : "جزر كايمان",
    "Kazakhstan" : "كازاخستان",
    "Lao People's Democratic Republic" : "جمهورية لاو الديمقراطية الشعبية",
    "Lebanon" : "لبنان",
    "Saint Lucia" : "سانت لوسيا",
    "Liechtenstein" : "ليختنشتاين",
    "Sri Lanka" : "سيريلانكا",
    "Liberia" : "ليبيريا",
    "Lesotho" : "ليسوتو",
    "Lithuania" : "ليتوانيا",
    "Luxembourg" : "لوكسمبورغ",
    "Latvia" : "لاتفيا",
    "Libya" : "ليبيا",
    "Morocco" : "المغرب",
    "Monaco" : "موناكو ",
    "Moldova, Republic of" : "جمهورية مولدوفا",
    "Montenegro" : "الجبل الأسود",
    "Saint Martin (French part)" : "سانت مارتن (الجزء الفرنسي)",
    "Madagascar" : "مدغشقر",
    "Marshall Islands" : "جزر مارشال",
    "North Macedonia" : "الجبل الأسود الشمالية",
    "Mali" : "مالي",
    "Myanmar" : "ميانمار",
    "Mongolia" : "منغوليا",
    "Macao" : "ماكاو",
    "Northern Mariana Islands" : "جزر ماريانا الشمالية",
    "Martinique" : "مارتينيك",
    "Mauritania" : "موريطانيا",
    "Montserrat" : "مونتسرات",
    "Malta" : "مالطا",
    "Mauritius" : "موريشيوس",
    "Maldives" : "جزر المالديف",
    "Malawi" : "ملاوي",
    "Mexico" : "المكسيك",
    "Malaysia" : "ماليزيا",
    "Mozambique" : "موزمبيق",
    "Namibia" : "ناميبيا",
    "New Caledonia" : "كاليدونيا الجديدة",
    "Niger" : "النيجر",
    "Norfolk Island" : "جزيرة نورفولك",
    "Nigeria" : "نيجيريا",
    "Nicaragua" : "نيكاراغوا",
    "Netherlands" : "هولندا",
    "Norway" : "النرويج",
    "Nepal" : "نيبال",
    "Nauru" : "ناورو",
    "Niue" : "نييوي",
    "New Zealand" : "نيوزلاندا ",
    "Oman" : "عمان",
    "Panama" : "بنما",
    "Peru" : "بيرو",
    "French Polynesia" : "بولينيزيا الفرنسية",
    "Papua New Guinea" : "بابوا غينيا الجديدة",
    "Philippines" : "الفلبين",
    "Pakistan" : "باكستان",
    "Poland" : "بولونيا",
    "Saint Pierre and Miquelon" : "سانت بيير وميكلون",
    "Pitcairn" : "جزر بيتكيرن",
    "Puerto Rico" : "بورتوريكو",
    "Palestine, State of" : "فلسطين",
    "Portugal" : "البرتغال",
    "Palau" : "بالاو",
    "Paraguay" : "باراغواي",
    "Qatar" : "قطر",
    "Réunion" : "ريونيون",
    "Romania" : "رومانيا",
    "Serbia" : "صربيا ",
    "Russian Federation" : "روسيا ",
    "Rwanda" : "رواندا",
    "Saudi Arabia" : "السعودية ",
    "Solomon Islands" : "جزر سليمان",
    "Seychelles" : "سيشيل",
    "Sudan" : "السودان",
    "Sweden" : "السويد",
    "Singapore" : "سنغافورة",
    "Saint Helena, Ascension and Tristan da Cunha" : "سانت هيلينا وأسينشين وتريستان دا كونا",
    "Slovenia" : "سلوفينيا",
    "Svalbard and Jan Mayen" : "سفالبارد وجان ماين",
    "Slovakia" : "سلوفاكيا",
    "Sierra Leone" : "سيراليون",
    "San Marino" : "سان مارينو",
    "Senegal" : "السنيغال",
    "Somalia" : "الصومال",
    "Suriname" : "سورينام",
    "South Sudan" : "جنوب السودان",
    "Sao Tome and Principe" : "ساو تومي وبرينسيبي",
    "El Salvador" : "السلفادور",
    "Sint Maarten (Dutch part)" : "سانت مارتن (الجزء الهولندي)",
    "Syrian Arab Republic" : "سوريا",
    "Eswatini" : "إسواتيني",
    "Turks and Caicos Islands" : "جزر تركس وكايكوس",
    "Chad" : "تشاد",
    "French Southern Territories" : "مدن جنوب فرنسا",
    "Togo" : "توجو",
    "Thailand" : "تايلاند",
    "Tajikistan" : "طاجيكستان",
    "Tokelau" : "توكيلاو",
    "Timor-Leste" : "تيمور الشرقية",
    "Turkmenistan" : "تركمانستان",
    "Tunisia" : "تونس",
    "Tonga" : "تونغا",
    "Turkey" : "تركيا",
    "Trinidad and Tobago" : "ترينيداد وتوباغو",
    "Tuvalu" : "توفالو",
    "Taiwan, Province of China" : "مقاطعة تايوان الصينية",
    "Tanzania, United Republic of" : "جمهورية تنزانيا المتحدة",
    "Ukraine" : "أوكرانيا",
    "Uganda" : "أوغندا",
    "United States Minor Outlying Islands" : "جزر الولايات المتحدة البعيدة الصغرى",
    "United States of America" : "الولايات المتحدة الأمريكية",
    "Uruguay" : "أوروغواي",
    "Uzbekistan" : "أوزبكستان",
    "Holy See" : "الكرسي الرسولي دولة الفاتيكان",
    "Saint Vincent and the Grenadines" : "سانت فنسنت وجزر غرينادين",
    "Venezuela, Bolivarian Republic of" : "جمهورية فنزويلا البوليفارية",
    "Virgin Islands, British" : "جزر العذراء، البريطانية",
    "Virgin Islands, U.S." : "جزر العذراء، الأمريكية",
    "Viet Nam" : "فييتنام",
    "Vanuatu" : "فانواتو",
    "Wallis and Futuna" : "جزر واليس وفوتونا",
    "Samoa" : "ساموا",
    "Yemen" : "اليمن",
    "Mayotte" : "مايوت",
    "South Africa" : "إفريقيا الجنوبية",
    "Zambia" : "زامبيا",
    "Zimbabwe" : "زيمبابوي",
    "Background blur" : "تضبيب خلفية الصورة",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "تعذر التحقُّق من دعم تحميل WASM. يرجى التحقق يدويًا مما إذا كان خادوم الويب لديك يتعامل مع ملفات `.wasm`.",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "لم يتم إعداد خادوم الويب لديك بالشكل الصحيح للتعامل مع ملفات `.wasm`. عادةً ما تكون هذه مشكلة في تكوين خادوم الويب Nginx. بالنسبة إلى الخلفية الضبابية، فإنها تحتاج إلى التعديل كذلك للتعامل مع ملفات \".wasm\". قارن إعدادات Nginx بالإعدادات الموصى بها في وثائق النظام.",
    "Talk configuration values" : "قيم تهيئة تطبيق \"المحادثة\" Talk",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "يتم دعم فرض مدة المكالمة فقط مع نظام cron. الرجاء تمكين cron النظام أو إزالة تكوين \"max_call_duration\".",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "قيم `max_call_duration` الصغيرة (المضبوطة حاليًا على %d) غير قابلة للتنفيذ بسبب القيود الفنية. يتم تنفيذ مهمة الخلفية كل 5 دقائق فقط، لذا استخدمها على مسؤوليتك الخاصة.",
    "Federation" : "الربط عبر السحابة الموحدة",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "يوصى بشدة بتهيئة \"memcache.locking\" عند تمكين المحادثة الاتحادية.",
    "High-performance backend" : "خلفية أعلى اداء",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "لم يتم تكوين واجهة خلفية عالية الأداء لتشغيل تطبيق \"المحادثة\" Talk من نكست كلاود. بدون واجهة خلفية عالية الأداء لا يمكن التعامل إلا مع عدد محدود من المكالمات (بحد أقصى 2-3 مشاركين). يُرجى إعداد الواجهة الخلفية عالية الأداء لضمان عمل المكالمات التي تضم أعداداً أكبر من المشاركين.\n\n\n ",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "وضع \"conversation_cluster\" في الواجهة الخلفية عالية الأداء صار قديمًا ولن يتم دعمه بعد الآن في الإصدارات القادمة. الواجهة الخلفية عالية الأداء تدعم التجميع الحقيقي real-clustering في الوقت الحالي والذي يجب استخدامه بدلاً من ذلك.",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "لقد أصبح تحديد العديد من الخوادم الخلفية عالية الأداء غير مستحسن ولن يتم دعمه بعد الآن في الإصدارات القادمة. و بدلاً من ذلك، يجب إعداد موازن التحميل load balancer مع خوادم الإشارات المجمعة وتكوينه في إعدادات تطبيق \"المحادثة\" Talk.",
    "High-performance backend not configured correctly" : "خلفية الأداء العالي HP backend ليست مُهيّأةً بالطريقة الصحيحة",
    "Error: Cannot connect to server" : "خطأ: لا يمكن الاتصال بالخادم",
    "Error: Server did not respond with proper JSON" : "خطأ: الخادم لم يجب جيدا JSON",
    "Error: Certificate expired" : "خطأ: انتهت صلاحية الشهادة",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "خطأ: أوقات النظام لخادوم نكست كلاود وخادوم الأداء العالي High Performance في الخلفية غير متزامنة. يرجى التأكد من أن كلا الخادومين متصلان بخادوم توقيت موحد أو قم بمزامنة وقتيهما يدوياً.",
    "Could not get version" : "تعذر الحصول على الإصدار",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "خطأ: إصدار قيد التشغيل: {version} ؛ يحتاج الخادم إلى التحديث حتى يكون متوافقًا مع هذا الإصدار من تطبيق Talk",
    "Error: Server responded with: {error}" : "خطأ: الخادم اجاب بـ: {error}",
    "Error: Unknown error occurred" : "خطأ: غير معروف",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "تحذير: الخادوم في الإصدار الذي تعمل عليه: {version}؛ لا يدعم جميع ميزات هذا الإصدار من تطبيق \"المحادثة\" Talk، و هو يفتقد للميزات: {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "يوصى بشدة بتهيئة ذاكرة تخزين مؤقت cache عند تشغيل تطبيق \"المحادثة\" Talk في نكست كلاود بواجهة خلفية عالية الأداء .",
    "Client Push" : "دفع المعلومات من جهة العميل Client Push",
    "Recording backend" : "خلفية التسجيل",
    "Using the recording backend requires a High-performance backend." : "لاستعمال تسجيل المحادثات في الخلفية يلزمك خلفية عالية الأداء.",
    "No recording backend configured" : "لاتوجد خلفية عالية الأداء للتسجيل",
    "SIP configuration" : "إعدادات SIP",
    "Using the SIP functionality requires a High-performance backend." : "لاستعمال خاصية الاتصال الهاتفي SIP يلزمك خلفية عالية الأداء.",
    "No SIP backend configured" : "لاتوجد خلفية عالية الأداء لإدارة جلسات المكالمات SIP",
    "Invalid date, date format must be YYYY-MM-DD" : "تاريخ غير صحيح, يجب أن يكون تنسيق التاريخ YYYY-MM-DD",
    "Conversation not found" : "المحادثة غير موجودة",
    "Path is already shared with this conversation" : "المسار سبقت مشاركته سلفاً مع هذه المحادثة",
    "Chat, video & audio-conferencing using WebRTC" : "الدردشة والفيديو والمؤتمرات الصوتية باستخدام WebRTC",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "الدردشة والفيديو والمؤتمرات الصوتية باستخدام WebRTC\n\n * 💬 **الدردشة** يأتي تطبيق المحادثة Talk في نكست كلاود مع محادثة نصية بسيطة، مما يسمح لك بمشاركة أو تحميل الملفات من تطبيق الملفات Files  في نكست كلاود أو من الجهاز المحلي، و الإشارة إلى المشاركين الآخرين. \n* 👥 **مكالمات خاصة وجماعية وعامة ومحمية بكلمة مرور! ** قم بدعوة شخص ما أو مجموعة كاملة أو أرسل رابطًا عامًا للدعوة لإجراء مكالمة.\n * 🌐 **الدردشات الموحدة** قم بالدردشة مع مستخدمي نكست كلاود الآخرين على خوادمهم \n* 💻 **مشاركة الشاشة!** شارك شاشتك مع المشاركين في مكالمتك. \n* 🚀 **التكامل مع تطبيقات نكست كلاود الأخرى** مثل الملفات والتقويم وحالة المستخدم ولوحة المعلومات وأتمتة سير العمل والخرائط و اللاقط الذكي وجهات الاتصال و رزم البطاقات وغير ذلك الكثير. \n* 🌉 **المزامنة مع حلول الدردشة الأخرى** من خلال دمج [Matterbridge] (https://github.com/42wim/matterbridge/) في Talk، يمكنك بسهولة مزامنة الكثير من حلول الدردشة الأخرى مع تطبيق المحادثة Talk في نكست كلاود، و كذلك بالعكس.",
    "Leave call" : "مغادرة المكالمة",
    "Navigating away from the page will leave the call in {conversation}" : "الخروج من هذه الصفحة سيؤدي لمغادرة المكالمة في {conversation}",
    "Stay in call" : "البقاء في المكالمة",
    "Duplicate session" : "تكرار الجلسة",
    "Discuss this file" : "مناقشة هذا الملف",
    "Loading …" : "التحميل جارٍ …",
    "Share this file with others to discuss it" : "مشاركة هذا الملف للمناقشة",
    "Join conversation" : "انضمام للمحادثة",
    "Share this file" : "مشاركة هذا الملف",
    "Error occurred when joining the conversation" : "حدث خطأ أثناء الانضمام إلى المحادثة",
    "This conversation is password-protected." : "هذه المحادثة محمية بكلمة مرور.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "لقد اكتشفنا عدة محاولات غير صالحة لكلمة المرور من عنوان IP الخاص بك. لذلك سوق يتم تقييد محاولتك التالية لمدة تصل إلى 30 ثانية.",
    "The password is wrong. Try again." : "كلمة المرور خاطئة. حاول مرة أخرى.",
    "Password" : "الكلمة السرية",
    "Submit" : "إرسال ",
    "Error requesting the password." : "خطأ في طلب كلمة المرور",
    "Request password" : "طلب كلمة المرور",
    "This conversation has ended" : "المحادثة انتهت",
    "Close Talk sidebar" : "إغلاق الشريط الجانبي لتطبيق Talk",
    "Open Talk sidebar" : "فتح الشريط الجانبي لتطبيق Talk",
    "Everyone" : "الجميع",
    "Users and moderators" : "الأعضاء والمشرفين",
    "Moderators only" : "المشرفين فقط",
    "Disable calls" : "تعطيل المكالمات",
    "Save changes" : "حفظ التعديلات",
    "Saving …" : "جاري الحفظ…",
    "Saved!" : "تم الحفظ!",
    "Limit to groups" : "التقيد إلى مجموعات",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "عند تحديد مجموعة واحدة، الاعضاء في هذه المجموعة فقط سيشاركون في هذه المحادثة.",
    "Guests can still join public conversations." : "الضيوف بإمكانهم الانضمام للمحادثات العامة.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "المستخدمين الذين لا يمكنهم استخدام التحدث Talk بعد الآن سيظهورن كمشاركين في قائمة المحادثات السابقة وأيضًا سيتم حفظ رسائل محادثاتهم.",
    "Limit using Talk" : "تقييد استخدام تطبيق التحدث",
    "Limit creating a public and group conversation" : "تقييد إنشاء محادثات عامة او جماعية",
    "Limit creating conversations" : "تقييد انشاء المحادثات",
    "Limit starting a call" : "تقييد بدء مكالمة",
    "Limit starting calls" : "تقييد بدء المكالمات",
    "When a call has started, everyone with access to the conversation can join the call." : "في حين مكالمة بدأت، الجميع بصلاحية للمحادثات بإمكانه الانضمام للمكالمة.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "تم تثبيت الروبوتات التالية على هذا الخادوم. في الوثائق، يمكنك العثور على تفاصيل حول كيفية {linkstart1} إنشاء روبوتك الخاص{linkend} أو {linkstart2} قائمة الروبوتات {linkend} لتمكينها على خادومك.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "لم يتم تثبيت أي روبوتات على هذا الخادوم. في الوثائق، يمكنك العثور على تفاصيل حول كيفية {linkstart1} إنشاء روبوتك الخاص{linkend} أو {linkstart2} قائمة الروبوتات {linkend} لتمكينها على خادومك.",
    "Description is not provided" : "الوصف غير موجود",
    "Locked for moderators" : "مقفل للمشرفين",
    "Enabled" : "مُفعّل",
    "Disabled" : "معطّل",
    "Bots settings" : "إعدادات الروبوتات Bots",
    "State" : "الحالة",
    "Name" : "الاسم",
    "Last error" : "آخر خطأ",
    "Total errors count" : "العدد الإجمالي للأخطاء",
    "Find more bots" : "أعثُر على المزيد من الروبوتات",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "يمكن تكوين الخوادم الموثوقة في {linkstart} صفحة إعدادات المشاركة {linkend}.",
    "Beta" : "تجريبي",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "المحادثات والمكالمات الاتحادية تعمل بالفعل. سيتم إضافة إمكانية التعامل مع المرفقات في إصدار مستقبلي.",
    "Enable Federation in Talk app" : "تمكين تطبيق \"المحادثة\" من التواصل عبر السحابة الموحدة",
    "Permissions" : "التصريحات",
    "Allow users to be invited to federated conversations" : "السماح للمستخدِمين بأن تتم دعوتهم إلى المحادثات الاتحادية",
    "Allow users to invite federated users into conversation" : "السماح للمستخدِمين بدعوة مستخدِمين من السحابة الموحدة إلى المحادثة ",
    "Only allow to federate with trusted servers" : "السماح فقط بالاتحاد مع الخوادم الموثوقة",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "عند تحديد مجموعة واحدة على الأقل، يمكن لأشخاص المجموعات المدرجة فقط دعوة المستخدِمين من السحابة الموحدة إلى المحادثة.",
    "Groups allowed to invite federated users" : "المجموعات التي يحق لها دعوة مستخدِمين من السحابة الموحدة",
    "Select groups …" : "تحديد المجموعات ...",
    "All messages" : "كافة الرسائل",
    "@-mentions only" : "@-إشارة فقط",
    "Off" : "إيقاف",
    "General settings" : "الإعدادات العامة",
    "Default notification settings" : "إعدادات الإشعارات الافتراضية",
    "Default group notification" : "تنبيه المجموعة الافتراضي",
    "Default group notification for new groups" : "تنبيه المجموعة الافتراضي للمجموعات الجديدة",
    "Integration into other apps" : "الربط مع تطبيقات آخرى",
    "Allow conversations on files" : "السماح بالمحادثات على الملفات",
    "Allow conversations on public shares for files" : "السماح للمحادثات عبر مشاركة الملفات العامة",
    "End-to-end encrypted calls" : "محادثات مشفرة من الحدّ للحدّ",
    "Enable encryption" : "تمكين التشفير",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "تتطلب المكالمات المشفرة من الحد للحد باستخدام جسر SIP مُهيّإٍ إصداراً أحدث من الواجهة الخلفية للأداء العالي وجسر SIP.",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "الهواتف النقالة العميلة لا تدعم المكالمات المشفرة من الحد للحد في الوقت الحاضر.",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "بالنقر فوق الزر أعلاه، يتم إرسال المعلومات الواردة في النموذج إلى خوادم شركة Struktur AG. يمكنك العثور على مزيد من المعلومات على {linkstart} spreed.eu {linkend}.",
    "Pending" : "معلّق",
    "Error" : "خطأ",
    "Blocked" : "محجوب",
    "Active" : "فعال",
    "Expired" : "منتهي",
    "Never" : "مُطلَقاً",
    "The trial could not be requested. Please try again later." : "لا يمكن طلب التجربة. يرجى إعادة المحاولة لاحقًا. ",
    "The account could not be deleted. Please try again later." : "لا يمكن حذف الحساب، يرجى المحاولة لاحقا.",
    "Hosted High-performance backend" : "خلفية مستضافة عالية الأداء ",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "يوفر شريكنا Struktur AG خدمة حيث يمكن طلب خادم التشوير المستضاف. لهذا ما عليك سوى ملء النموذج أدناه وسيطلبه نكست كلاود الخاص بك. وبمجرد تعيين الخادم لك، سيتم ملء بيانات الاعتماد تلقائيًا. سيؤدي هذا إلى الكتابة فوق إعدادات خادم التشوير الحالي.",
    "URL of this Nextcloud instance" : "الرابط لهذا الخادم السحابي نكست كلاود",
    "Full name of the user requesting the trial" : "الاسم الكامل للمستخدم الذي يطلب التجربة",
    "Email of the user" : "البريد الالكتروني للمستخدم ",
    "Language" : "اللغة",
    "Country" : "البلد",
    "Request signaling server trial" : "طلب تجربة خادم التشوير",
    "You can see the current status of your hosted signaling server in the following table." : "يمكنك رؤية الحالة الحالية لخادم التشوير المستضاف في الجدول التالي.",
    "Status" : "الحالة",
    "Created at" : "انشأت في",
    "Expires at" : "انتهت في",
    "Limits" : "التقييد",
    "Yes" : "نعم",
    "No" : "لا",
    "Delete the signaling server account" : "حذف حساب خادم التشوير ",
    "_%n user_::_%n users_" : ["%n مستخدم ","%n مستخدم ","%n مستخدم ","%n مستخدم ","%n مستخدم ","%n مستخدم"],
    "Installed version: {version}" : "الاصدار المثبت: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "يمكنك تثبيت Matterbridge لربط Nextcloud Talk ببعض الخدمات الأخرى ، قم بزيارة {linkstart1} صفحة جيت هب {linkend} الخاصة بهم لمزيد من التفاصيل. قد يستغرق تنزيل التطبيق وتثبيته بعض الوقت. في حالة انتهاء المهلة، يرجى تثبيته يدويًا من {linkstart2} متجر تطبيقات نكست كلود {linkend}.",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "كود \"ماتر بريدج\" Matterbridge binary لايملك الأذونات الصحيحة المطلوبة. رجاءً، تأكد من أن المستخدِم مالك ملف كود \"ماتر بريدج\" Matterbridge binary يحمل الصلاحيات اللازمة بحيث يمكن تنفيذه. يمكن إيجاده في: \"/…/nextcloud/apps/talk_matterbridge/bin/\".",
    "Matterbridge binary was not found or couldn't be executed." : "لم يتم العثور على ملف Matterbridge الثنائي أو تعذر تنفيذه.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "يمكنك أيضًا تعيين المسار إلى ثنائي Matterbridge يدويًا عبر التكوين. راجع {linkstart} وثائق تكامل Matterbridge {linkend} للحصول على مزيد من المعلومات.",
    "Downloading …" : "جاري التحميل…",
    "Install Talk Matterbridge" : "تثبيت Talk Matterbridge",
    "An error occurred while installing the Matterbridge app" : "حدث خطأ أثناء تنصيب تطبيق Matterbridge",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "حدث خطأ أثناء تنصيب the Talk Matterbridge. رجاءً، قُم بتنصيبه يدوياً",
    "Failed to execute Matterbridge binary." : "فشل تنفيذ برنامج Matterbridge الثنائي.",
    "Matterbridge integration" : "تكامل Matterbridge",
    "Enable Matterbridge integration" : "تعطيل تكامل Matterbridge",
    "Status: Checking connection" : "الحالة: فحص الاتصال",
    "OK: Running version: {version}" : "ممتاز: الاصدار التشغيلي: {version}",
    "Error: Server seems to be a Signaling server" : "خطأ: يبدو أن الخادوم هو خادوم إشارة Signaling server",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "خطأ: أوقات النظام لخادوم نكست كلاود وخادوم التسجيل الصوتي للمكالمات في الخلفية غير متزامنة. يرجى التأكد من أن كلا الخادومين متصلان بخادوم توقيت موحد أو قم  بمزامنة وقتيهما يدوياً.",
    "Recording backend URL" : "عنوان URL خلفية التسجيل",
    "Validate SSL certificate" : "التحقق من صلاحية شهادة SSL",
    "Delete this server" : "حذف هذا الخادم",
    "Test this server" : "جرّب هذا الخادم",
    "Disabled for all calls" : "تمّ تعطيله لكل المكالمات",
    "Enabled for all calls" : "تمّ تمكينه لكل المكالمات",
    "Configurable on conversation level by moderators" : "يمكن تهيئته على مستوى المحادثة من قِبَل المشرفين",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "أعدادات PHP ـ  \"upload_max_filesize\" أو \"post_max_size\" فقط ستسمح برفع ملفات ٍإلى  {maxUpload}.",
    "Recording backend settings saved" : "تمّ حفظ إعدادات خلفية التسجيل recording backend",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "المشرفون يمكنهم تمكين الإذونات على مستوى المحادثة. الإذن بالتسجيل مطلوب من كل مشارك قبل الانضمام لكل مكالمة في هذه المحادثة.",
    "The consent to be recorded will be required for each participant before joining every call." : "الإذن بالتسجيل سيُطلب من كل مشارك قبل الانضمام لكل مكالمة. ",
    "The consent to be recorded is not required." : "الإذن بالتسجيل ليس مطلوباً.",
    "Recording backend configuration is only possible with a High-performance backend." : "تهيئة خلفية التسجيل ممكنة فقط بوجود خلفية عالية الأداء.",
    "Add a new recording backend server" : "إضافة خادم واجهة خلفية للتسجيل جديد",
    "Shared secret" : "السر المشترك",
    "Recording consent" : "الإذن بالتسجيل",
    "Recording transcription" : "مستنسخ التسجيل ",
    "Automatically transcribe call recordings with a transcription provider" : "القيام تلقائياً باستنساح تسجيلات المكالمات عبر مزود استنساخ",
    "Automatically summarize call recordings with transcription and summary providers" : "القيام تلقائياً بتلخيص تسجيلات المكالمات عبر مزود استنساخ و تلخيص",
    "SIP configuration saved!" : "تم حفظ تكوين SIP!",
    "SIP configuration is only possible with a High-performance backend." : "تهيئة إدارة جلسات المكالمات SIP ممكنة فقط بوجود خلفية عالية الأداء.",
    "Enable SIP Dial-out option" : "تمكين خيار الطلب الهاتفي SIP.",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "يحتاج خادوم الإشارة Signaling server إلى التحديث إلى ميزة الطلب الهاتفي SIP المدعومة.",
    "Restrict SIP configuration" : "تقييد إعدادات SIP",
    "Enable SIP configuration" : "تفعيل إعدادات SIP",
    "Only users of the following groups can enable SIP in conversations they moderate" : "السماح فقط للمستخدمين من المجموعات التالية بتفعيل SIP في اشرافهم على المحادثات.",
    "Phone number (Country)" : "رقم الجوال (الدولة)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "هذه المعلومات مرسله من بريد الدعوة وظاهرة ايضا في الشريط الجانبي لجميع المشاركين.",
    "Nextcloud base URL" : "عنوان URL الأساسي لنكست كلاود",
    "Talk Backend URL" : "عنوان URL لخلفية \"المحادثة\" Talk",
    "WebSocket URL" : "عنوان URL لـ\"مَقبَس الوِب\" WebSocket",
    "Available features" : "الخصائص المُتَاحة",
    "Error code" : "رقم الخطأ",
    "Error: Websocket connection failed. Check browser console" : "خطأ: فشل الاتصال عن طريق \"مقبس الوب\" WebSocket. أنظُر طَرَفِيّة المُتصَفِّح browser console",
    "High-performance backend URL" : "رابط خلفية أعلى اداء",
    "Missing High-performance backend warning hidden" : "التحذير من عدم وجود خلفية للأداء العالي لن يتم إظهاره",
    "High-performance backend settings saved" : "تم حفظ إعدادات الواجهة الخلفية عالية الأداء",
    "Nextcloud Talk setup not complete" : "تهيئة \"المحادثة\" Talk من نكست كلاود لم تكتمل بعدُ.",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "يرجى ملاحظة أنه في المكالمات التي يكون فيها عدد المشاركين أكثر من 2 دون استخدام خلفية الأداء العالي، فمن المرجح أن يواجه المشاركون مشكلات في الاتصال قد يسبب تحميلًا عاليًا على الأجهزة المشاركة.",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "قُم بتثبيت خلفية الأداء العالي لضمان العمل بسلاسة لمكالمات متعددة المتشاركين.",
    "Nextcloud portal" : "بوابة نكست كلاود",
    "Quick installation guide" : "دليل التثبيت السريع",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "خلفية الأداء العالي لازمة لإجراء مكالمات ومحادثات فيها متشاركون عديدون. وبدون هذه الخلفية، يتعين على جميع المشاركين تحميل مقاطع الفيديو الخاصة بهم بشكل فردي لكل مشارك آخر؛ الأمر الذي قد يتسبب في حدوث مشكلات في الاتصال وزيادة الحمل على الأجهزة المشاركة.",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "يوصى بشدة بإعداد ذاكرة تخزين مؤقتة موزعة distriburted cache عند استخدام \"المحادثة\" Talk من نكست كلاود مع خلفية للأداء العالي.",
    "Add High-performance backend server" : "إضافة خادوم خلفية الأداء العالي",
    "Warn about connectivity issues in calls with more than 2 participants" : "تحذير حول إشكاليات في الاتصال بالنسبة للمكالمات التي فيها أكثر من 2 مُشَارِكَيْن.",
    "STUN server URL" : "عنوان URL لخادم STUN",
    "The server address is invalid" : "عنوان الخادم غير صالح",
    "STUN settings saved" : "تم حفظ إعدادات خادم STUN",
    "STUN servers" : "خوادم STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "يتم استخدام خادم STUN لتحديد عنوان IP العام للمشاركين خلف جهاز توجيه.",
    "Add a new STUN server" : "إضافة خادم STUN جديد",
    "{schema} scheme must be used with a domain" : "{schema} يجب أن يستخدم من نطاق معين ",
    "{option1} and {option2}" : "{خيار1} و {خيار2}",
    "{option} only" : "{option} فقط ",
    "OK: Successful ICE candidates returned by the TURN server" : "حسنًا: تم إرجاع مرشحي ICE بواسطة خادم TURN بنجاح",
    "Error: No working ICE candidates returned by the TURN server" : "خطأ: لم يتم إرجاع أي من مرشحي ICE بواسطة خادم TURN",
    "Testing whether the TURN server returns ICE candidates" : "تجربة ما إذا كان خادم TURN يعرض مرشحات ICE",
    "TURN server schemes" : "نظم خادم TURN",
    "TURN server URL" : "عنوان URL لخادم TURN",
    "TURN server secret" : "سر خادم TURN",
    "TURN server protocols" : "بروتوكلات خادم TURN",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "يتم استخدام خادم TURN لتوكيل مرور المشاركين خلف جدار الحماية. إذا لم يتمكن المشاركون الأفراد من الاتصال بالآخرين، فمن المرجح أن يكون خادم TURN مطلوبًا. راجع {linkstart} هذه الوثائق {linkend} للحصول على إرشادات الإعداد.",
    "TURN settings saved" : "تم حفظ إعدادات خادم TURN",
    "TURN servers" : "خوادم TURN",
    "Add a new TURN server" : "إضافة خادم TURN جديد",
    "Failed" : "فشل",
    "OK" : "موافق",
    "Checking …" : "جاري التحقق … ",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "فشل: تم تعطيل WebAssembly أو أنه غير مدعوم في هذا المتصفح. يرجى تمكين WebAssembly أو استخدام متصفح يدعمه لإجراء الفحص.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "فشل: لم يتم إرجاع ملفات \".wasm\" و \".tflite\" بشكل صحيح من قبل خادم الويب. الرجاء مراجعة قسم \"متطلبات النظام\" في وثائق تطبيق Talk.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "حسنًا: تم إرجاع ملفات \".wasm\" و \".tflite\" بشكل صحيح من قبل خادم الويب.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "يبدو أن إعدادات PHP و Apache غير متوافقة. يرجى ملاحظة أنه لا يمكن استخدام PHP إلا مع الوحدة النمطية MPM_PREFORK ولا يمكن استخدام PHP-FPM إلا مع الوحدة النمطية MPM_EVENT.",
    "Web server setup checks" : "التحقق من تنصيب خادم الويب",
    "Files required for virtual background can be loaded" : "يمكن تحميل الملفات المطلوبة للخلفية الافتراضية",
    "Federated user" : "مستخدِم السحابة الموحدة",
    "Assign participants to rooms" : "تعيين المشاركين للغرف",
    "Configure breakout rooms" : "تهيئة الغرف الجانبية",
    "Number of breakout rooms" : "عدد الغرف الجانبية",
    "You can create from 1 to 20 breakout rooms." : "يمكنك إنشاء من 1 حتى 20 غرفة جانبية.",
    "Assignment method" : "طريقة التكليف",
    "Automatically assign participants" : "تعيين المشاركين تلقائيًا",
    "Manually assign participants" : "تعيين المشاركين يدويًا",
    "Allow participants to choose" : "السماح للمشاركين بالاختيار",
    "Create rooms" : "إنشاء غرف",
    "Confirm" : "تأكيد",
    "Create breakout rooms" : "إنشاء غرف جانبية",
    "Reset" : "إعادة الضبط",
    "Delete breakout rooms" : "حذف الغرف الجانبية",
    "Room {roomNumber}" : "غرفة {roomNumber}",
    "Current breakout rooms and settings will be lost" : "سوف يحدث فقد للغرف الجانبية والإعدادات الحالية",
    "Cancel" : "إلغاء",
    "Unassigned participants" : "المشاركون غير المعينين",
    "Back" : "العودة",
    "Assign" : "كَلِّف",
    "Add participant \"{user}\"" : "إضافة مشارك \"{user}\"",
    "Now" : "الآن",
    "Invalid calendar selected" : "التقويم الذي تمّ تحديده غير صحيح",
    "Invalid start time selected" : "وقت البداية الذي تمّ تحديده غير صحيح",
    "Invalid end time selected" : "وقت الانتهاء الذي تمّ تحديده غير صحيح",
    "Unknown error occurred" : "حدث خطأ غير معروف",
    "Sending no invitations" : "لم يتم إرسال أي دعوات",
    "{participant0} will receive an invitation" : "{participant0} سوف يستلم دعوةً",
    "{participant0} and {participant1} will receive invitations" : "{participant0} و {participant1} سوف يستلمان دعوةً",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}, {participant1} و %n آخرون سيستلمون دعواتٍ","{participant0}, {participant1} و %n آخرون سيستلمون دعواتٍ","{participant0}, {participant1} و %n آخرين سيستلمون دعواتٍ","{participant0}, {participant1} و%n آخرين سوف يستلمون دعواتٍ","{participant0}, {participant1} و %n آخرين سوف يستلمون دعواتٍ","{participant0}, {participant1} و %n آخرين سوف يستلمون دعواتٍ"],
    "Meeting created" : "تمّ إنشاء الاجتماع",
    "Upcoming meetings" : "الاجتماعات القادمة",
    "Schedule a meeting" : "جدولة اجتماع",
    "Meeting title" : "عنوان الاجتماع",
    "From" : "مِن :",
    "To" : "إلى :",
    "Calendar" : "الجدول الزمني",
    "Attendees" : "المشاركون",
    "Add attendees" : "إضافة إلى الحُضُور",
    "Save" : "حفظ",
    "Search participants" : "البحث عن مشاركين",
    "No results" : "دون أية نتيجة",
    "Done" : "تمّ",
    "Exit full screen (F)" : "خروج من ملء الشاشة (F)",
    "Full screen (F)" : "ملء الشاشة (F)",
    "Speaker view" : "عرض المتحدث",
    "Grid view" : "عرض كمخطط",
    "Recording consent is required" : "إذن التسجيل مطلوب",
    "This conversation is read-only" : "هذه المحادثة للقراءة فقط",
    "Conversation not found or not joined" : "المحادثة غير موجودة أو لم يتم الانضمام إليها",
    "Lobby is still active and you're not a moderator" : "صالة الاستقبال مازالت مفتوحة وأنت ليس مُنسِّقَاً",
    "Connection failed" : "تعذّر الاتصال",
    "Reload" : "إعادة تحميل",
    "{nickName} raised their hand." : "{nickName} رفع يده ",
    "A participant raised their hand." : "رفع مشارك يده. ",
    "Collapse stripe" : "طي الشريط ",
    "Expand stripe" : "توسيع الشريط ",
    "Previous page of videos" : "الصفحة السابقة للفيديوهات ",
    "Next page of videos" : "الصفحة التالية من الفيديوهات ",
    "Connecting …" : "جارٍ الاتصال…",
    "Calling …" : "الاتصال جارٍ ...",
    "Waiting for {user} to join the call" : "في انتظار انضمام {user} إلى المكالمة",
    "Waiting for others to join the call …" : "انتظار الآخريين للانضمام للمكالمة…",
    "You can invite others in the participant tab of the sidebar" : "بإمكانك اضافة مشاركيين آخريين من القائمة الجانبية",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "بإمكانك اضافة مشاركيين آخريين من القائمة الجانبية أو مشاركة الرابط لدعوة الآخريين!",
    "Share this link to invite others!" : "شارك هذا الرابط لدعوة الآخريين!",
    "Copy link" : "انسخ الرابط",
    "You are not allowed to enable audio" : "غير مسموح لك بتمكين الصوت",
    "No audio. Click to select device" : "لا يوجد صَوْت. أنقُر لاختيار الجهاز",
    "Mute audio" : "كتم الصوت",
    "Mute audio (M)" : "كتم الصوت (M)",
    "Unmute audio" : "تشغيل الصوت",
    "Unmute audio (M)" : "تشغيل الصوت (M)",
    "None" : "لا شيء",
    "Access to camera was denied" : "تم رفض الوصول للكاميرا",
    "Error while accessing camera: It is likely in use by another program" : "خطأ أثناء الوصول إلى الكاميرا: من المحتمل أن تكون قيد الاستخدام من قبل برنامج آخر",
    "Error while accessing camera" : "حدث خطأ اثناء الوصول للكاميرا",
    "You have been muted by a moderator" : "تم اغلاق المايكرفون الخاص بك من قبل المشرف",
    "Hide presenter video" : "إخفاء فيديو مقدم العرض",
    "You are not allowed to enable video" : "غير مسموح لك بتمكين الفيديو",
    "No video. Click to select device" : "لايوجد فيديو. أنقُر لاختيار الجهاز",
    "Disable video" : "تعطيل الفيديو",
    "Disable video (V)" : "تعطيل بالفيديو (V)",
    "Enable video" : "تفعيل الفيديو",
    "Enable video (V)" : "تفعيل الفيديو (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "تمكين الفيديو - سوف ينقطع اتصالك مؤقّتاً عند تمكين الفيديو للمرة الاولى",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "تفعيل الفيديو (v) - سيتم قطع اتصالك للحظات عند تشغيل الفيديو للمره الأولى",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "سماح الفيديو - سيتم قطع اتصالك للحظات عند تشغيل الفيديو للمره الاولى",
    "Show presenter" : "إظهار مقدم العرض",
    "You" : "أنت",
    "Mute" : "كتم الصوت",
    "Muted" : "تم كتم الصوت",
    "Show screen" : "اظهار الشاشة",
    "Stop following" : "ايقاف المتابعة",
    "Connection could not be established …" : "تعذر إنشاء الاتصال ...",
    "Connection was lost and could not be re-established …" : "انقطع الاتصال ولا يمكن إعادة إنشائه ...",
    "Connection could not be established. Trying again …" : "تعذر إنشاء الاتصال. المحاولة مرة اخرى …",
    "Connection lost. Trying to reconnect …" : "انقطع الاتصال. جارٍ محاولة إعادة الاتصال ...",
    "Connection problems …" : "مشاكلات في الاتصال …",
    "Collapse" : "طوي",
    "Expand" : "توسيع",
    "You need to be logged in to upload files" : "يجب عليك تسجيل الدخول لرفع الملفات",
    "Drop your files to upload" : "افلت الملفات لرفعها",
    "Conversation messages" : "رسائل المحادثة ",
    "Scroll to bottom" : "انتقل للاسفل",
    "Post message" : "إرسال الرسالة ",
    "Federated conversation" : "محادثة السحابة الموحدة",
    "Public conversation" : "محادثة عمومية",
    "Favorite" : "المفضلة",
    "Banned users" : "مستخدِمون محظورون",
    "Manage the list of banned users in this conversation." : "إدارة قائمة المستخدمين المحظورين في هذه المحادثة",
    "Manage bans" : "إدارة الحظر",
    "No banned users" : "لا يوجد مستخدِمون محظورون",
    "Banned by:" : "محظورٌ من قِبَل:",
    "Date:" : "التاريخ:",
    "Note:" : "ملاحظة:",
    "Hide details" : "إخفاء التفاصيل",
    "Show details" : "عرض التفاصيل",
    "Unban" : "رفع الحظر",
    "Error while updating conversation name" : "خطأ أثناء تحميل اسم المحادثة",
    "Error while updating conversation description" : "حدث خطأ أثناء تحديث وصف المحادثة",
    "Enter a name for this conversation" : "أدخِل اسماً لهذه المحادثة",
    "Edit conversation name" : "تعديل اسم المحادثة",
    "Edit conversation description" : "تحرير وصف المحادثة",
    "Enter a description for this conversation" : "ادخل وصفًا لهذه المحادثة ",
    "Picture" : "صورة",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "يمكن تمكين الروبوتات bots التالية في هذه المحادثة. تواصل مع إدارتك لتثبيت المزيد من برامج الروبوت على هذا الخادوم.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "لم يتم تثبيت أي روبوتات على هذا الخادم. تواصل مع إدارتك لتثبيت برامج الروبوت على هذا الخادوم.",
    "Disable" : "تعطيل",
    "Enable" : "تمكين",
    "Breakout rooms" : "الغرف الجانبية",
    "Manage breakout rooms" : "أدِر الغرف الجانبية",
    "Set up breakout rooms for this conversation" : "جهّز غرفاً جانبيةً لهذه المحادثة",
    "Please select a valid PNG or JPG file" : "يرجي اختيار ملف PNG أو JPG صالح",
    "Choose your conversation picture" : "إختَر صورة محادثتك",
    "Choose" : "إختر",
    "Error setting conversation picture" : "خطأ في تعيين صورة المحادثة",
    "Could not set the conversation picture: {error}" : "تعذّر تعيين صورة المحادثة: {error}",
    "Error cropping conversation picture" : "خطأ في اقتصاص صورة المحادثة",
    "Error removing conversation picture" : "خطأ في حذف صورة المحادثة",
    "Set emoji as conversation picture" : "تعيين إيموجي كصورة للمحادثة",
    "Set background color for conversation picture" : "تعيين لون الخلفية لصورة المحادثة",
    "Upload conversation picture" : "رفع صورة المحادثة",
    "Choose conversation picture from files" : "إختَر صورة للمحادثة من الملفات",
    "Remove conversation picture" : "حذف صورة المحادثة",
    "The file must be a PNG or JPG" : "يحب أن يكون الملف PNG أو JPG",
    "Set picture" : "تعيين الصورة",
    "Default permissions modified for {conversationName}" : "تم تعديل الأذونات الافتراضية لـ {ConversName}",
    "Could not modify default permissions for {conversationName}" : "تعذر تعديل الأذونات الافتراضية لـ {callingName}",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "تحرير الأذونات الافتراضية للمشاركين في هذه المحادثة. لا تؤثر هذه الإعدادات على المشرفين.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "في كل مرة يتم فيها تعديل الأذونات في هذا القسم، فإن الأذونات المخصصة التي سبق تعيينها للمشاركين الفرديين سيقع حذفها.",
    "All permissions" : "كل الأذونات",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "حصل المشاركون علي أذونات لبدء مكالمة، والانضمام إلى مكالمة، وتمكين الصوت والفيديو ، ومشاركة الشاشة.",
    "Restricted" : "مقيد",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "يمكن للمشاركين الانضمام إلى المكالمات، لكن لا يمكنهم تمكين الصوت أو الفيديو أو مشاركة الشاشة حتى يمنحهم الميسر الأذونات يدويًا.",
    "Advanced permissions" : "أذونات متقدمة",
    "Edit permissions" : "تحرير الأذونات",
    "Conversation settings" : "اعدادات المحادثة",
    "Basic Info" : "معلومات أساسية",
    "Personal" : "شخصي",
    "Moderation" : "الإدارة",
    "Setup overview" : "نظرة عامة على الإعداد",
    "Breakout Rooms" : "الغرف الجانبية",
    "Matterbridge" : "Matterbridge",
    "Bots" : "الروبوتات Bots",
    "Danger zone" : "منطقة خطر",
    "Archive conversation" : "أرشفة المحادثة",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "يتم إخفاء المحادثات المؤرشفة من قائمة المحادثات تلقائيّاً. ومع ذلك، ستظل تظهر عند البحث عن اسم المحادثة أو الوصول إلى قائمة المحادثات المؤرشفة.",
    "Do you really want to leave \"{displayName}\"?" : "هل ترغب حقاً في المغادرة، \"{displayName}\"؟",
    "You can archive this conversation instead." : "يمكنك أرشفة هذه المحادثة بدلاً عن ذلك.",
    "Leave conversation" : "غادر المحادثة",
    "You need to promote a new moderator before you can leave the conversation" : "تحتاج إلى إنشاء ميسر جديد قبل أن تتمكن من مغادرة المحادثة",
    "Delete conversation" : "احذف المحادثة",
    "Do you really want to delete \"{displayName}\"?" : "هل تريد حقا حذف \"{displayName}\" ؟",
    "Error while deleting conversation" : "حدث خطأ أثناء حذف المحادثة ",
    "Delete all chat messages" : "حذف جميع رسائل الدردشة",
    "Do you really want to delete all messages in \"{displayName}\"?" : "هل تريد حقًا حذف كافة الرسائل الموجودة في \"{displayName}\"؟",
    "Error while clearing chat history" : "خطأ أثناء مسح سجل الدردشة",
    "Be careful, these actions cannot be undone." : "كن حذرًا ، لا يمكن التراجع عن هذه الإجراءات.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "عند ترك المحادثة،ولإعادة الانضمام مرة أخرى إلى المحادثة المغلقة، فإن ذلك يتطلبدعوة. ويمكن إعادة الانضمام إلى المحادثة المفتوحة في أي وقت.",
    "Permanently delete this conversation." : "حذف هذه المحادثة بشكل دائم.",
    "Delete chat messages" : "حذف رسائل الدردشة",
    "Permanently delete all the messages in this conversation." : "حذف جميع الرسائل الموجودة في هذه المحادثة بشكل دائم.",
    "Custom expiration time" : "تخصيص إنتهاء الصلاحية",
    "Message expiration disabled" : "تم تعطيل انتهاء صلاحية الرسالة",
    "Message expiration set: {duration}" : "ضبط انتهاء صلاحية الرسالة: {duration}",
    "Error when trying to set message expiration" : "خطأ عند محاولة تعيين انتهاء صلاحية الرسالة",
    "Message expiration" : "نهاية صلاحية الرسالة",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "يمكن أن تنتهي صلاحية رسائل الدردشة بعد وقت معين. ملاحظة: لن يتم حذف الملفات التي تمّت مشاركتها في الدردشة عند المالك، و لكن لن تستمر مشاركتها مع الآخرين في المحادثة.",
    "Set message expiration" : "عيّن تاريخ انتهاء صلاحية الرسالة",
    "Current message expiration" : "التاريخ الحالي لانتهاء صلاحية الرسالة",
    "Password copied to clipboard" : "تمّ نسخ كلمة المرور إلى الحافظة",
    "Password could not be copied" : "تعذّر نسخ كلمة المرور",
    "Guest access" : "وصول الضيف",
    "Breakout rooms are not allowed in public conversations." : "الغرف الجانبية غير متاحة في حالة المحادثات العامة.",
    "Allow guests to join this conversation via link" : "السماح للضيوف بالانضمام إلى هذه المحادثة من خلال رابط",
    "Password protection" : "الحماية بكلمة السر",
    "This conversation is password-protected. Guests need password to join" : "المحادثة محمية بكلمة مرور. الضيوف محتاجون لكلمة المرور للانضمام",
    "Password protection is needed for public conversations" : "الحماية باستعمال كلمة المرور لازمة في حالة المحادثة العامة",
    "Set a password" : "تعيين كلمة المرور",
    "Change password" : "تغيير كلمة المرور",
    "Enter new password" : "أدخِل كلمة مرور جديدة",
    "Save password" : "حفظ كلمة المرور",
    "Copy password" : "إنسَخ كلمة المرور",
    "Guests are allowed to join this conversation via link" : "الضيوف مسموح لهم بالانضمام لهذه المحادثة عبر الرابط",
    "Guests are not allowed to join this conversation" : "الضيوف غير مسموح لهم بالانضمام لهذه المحادثة",
    "Resend invitations" : "إعادة إرسال الدعوات ",
    "This conversation is open to both registered users and users created with the Guests app" : "المحادثة مفتوحة لكل من المستخدِمين المسجلين و للضيوف المستحدثين عبر تطبيق الضيوف Guests app",
    "This conversation is open to registered users" : "المحادثة مفتوحة للمستخدِمين المسجلين",
    "This conversation is limited to the current participants" : "هذه المحادثة مقتصرةٌ على المشاركين الحاليين",
    "You opened the conversation to both registered users and users created with the Guests app" : "أنت قمت بفتح المحادثة لكل من المستخدِمين المسجلين و المستخدِمين المستحدثين عبر تطبيق الضيوف Guests app",
    "Error occurred when opening or limiting the conversation" : "حدث خطأ عند فتح أو تقييد الرد بالمحادثة ",
    "Open conversation to registered users, showing it in search results" : "فتح المحادثة للمستخدمين المسجلين، وإظهارها في نتائج البحث",
    "Also open to users created with the Guests app" : "و مفتوحةٌ أيضاً للضيوف  المستحدثين عبر تطبيق الضيوف Guests app",
    "Open conversation" : "فتح المحادثة",
    "Invalid language" : "لغة غير صالحة",
    "Start time: {date}" : "بدايةً من: {date}",
    "Start time has been updated" : "تم تحديث وقت البدء",
    "Error occurred while updating start time" : "حدث خطأ أثناء تحديث وقت البدء ",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "سيؤدي تمكين صالة الانتظار إلى إزالة الجميع باستثناء المشرفين من المكالمة الجارية.",
    "Enable lobby, restricting the conversation to moderators" : "تمكين صالة الانتظار، و قصر المحادثة على المشرفين",
    "Meeting start time" : "وقت بدء الإجتماع ",
    "Start time (optional)" : "بداية الوقت (اختياري)",
    "Import email participants" : "استيراد المشاركين في البريد الإلكتروني",
    "You can import a list of email participants from a CSV file." : "يمكنك استيراد قائمة المشاركين في البريد الإلكتروني من ملف CSV.",
    "Poll drafts" : "مسودات الاستبيان",
    "Browse poll drafts" : "استعراض مسودات الاستبيان",
    "Error occurred when locking the conversation" : "حدث خطأ أثناء قفل المحادثة ",
    "Error occurred when unlocking the conversation" : "حدث خطأ أثناء إزالة قفل المحادثة ",
    "Lock conversation" : "قفل المحادثة",
    "This will also terminate the ongoing call." : "سيؤدي هذا أيضًا إلى إنهاء المكالمة الجارية.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "قفل المحادثة لمنع أي شخص من نشر الرسائل أو بدء المكالمات",
    "Edit" : "تعديل",
    "More information" : "المزيد من المعلومات",
    "Delete" : "حذف ",
    "Add new bridged channel to current conversation" : "إضافة قناة وصل جديدة للمحادثة الحالية ",
    "unknown state" : "حالة غير معروفة",
    "running" : "فعال",
    "not running, check Matterbridge log" : "لا يعمل، تحقق من سجل Matterbridge",
    "not running" : "غير فعال",
    "Bridge saved" : "تم الحفظ ",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "يمكنك ربط القنوات من مختلف أنظمة المراسلة الفورية باستخدام Matterbridge.",
    "More info on Matterbridge" : "مزيد من المعلومات حول Matterbridge.",
    "Messaging systems" : "نظم التراسل",
    "Enable bridge" : "غير متاح ",
    "Show Matterbridge log" : "إظهار سجل Matterbridge",
    "Log content" : "محتوى سجل الأحداث",
    "Only moderators are allowed to mention @all" : "فقط المشرفون يحق لهم الإشارة إلى الجميع  @all",
    "All participants are allowed to mention @all" : "جميع المشاركين مسموح لهم بالإشارة إلى الجميع @all",
    "Participants are now allowed to mention @all." : "المشاركون غير مسموح لهم بالإشارة إلى الجميع @all",
    "Mentioning @all has been limited to moderators." : "صلاحية الإشارة إلى الجميع @all مقتصرة فقط على المشرفين.",
    "Allow participants to mention @all" : "السماح للمشاركين بالإشارة إلى الجميع @all",
    "Mention permissions" : "صلاحية الإشارة لآخرين",
    "Notifications" : "التنبيهات",
    "Notify about calls in this conversation" : "الإخطار حول المكالمات فى هذه المحادثة",
    "Important conversation" : "محادثة مهمة",
    "Recording consent is required for calls in this conversation" : "الإذن بالتسجيل مطلوبٌ لكل المكالمات في هذه المحادثة",
    "Recording consent is not required for calls in this conversation" : "الإذن بالتسجيل ليس مطلوباً لكل المكالمات",
    "Recording consent requirement was updated" : "تم تحديث متطلبات الإذن بالتسجيل",
    "Error occurred while updating recording consent" : "حدث خطأ أثناء تحديث الإذن بالتسجيل",
    "Recording Consent" : "الإذن بالتسجيل ",
    "Recording consent cannot be changed once a call or breakout session has started." : "لا يمكن تغيير الموافقة على التسجيل بعد بدء المكالمة أو الجلسة الجانبية.",
    "Require recording consent before joining call in this conversation" : "أطلُب الإذن بالتسجيل قبل الانضمام لهذه المحادثة",
    "Recording consent is required for all calls" : "الإذن بالتسجيل مطلوبٌ لكل المكالمات",
    "SIP dial-in is now possible without PIN requirement" : "أصبح الاتصال عبر SIP ممكنًا الآن بدون الحاجة إلى رقم التعريف الشخصي",
    "SIP dial-in is now enabled" : "تم تمكين اتصال SIP الآن",
    "SIP dial-in is now disabled" : "تم تعطيل اتصال SIP الآن",
    "Error occurred when enabling SIP dial-in" : "حدث خطأ أثناء تمكين اتصال SIP",
    "Error occurred when disabling SIP dial-in" : "حدث خطأ أثناء تعطيل اتصال SIP",
    "Phone and SIP dial-in" : "الاتصال الهاتفي dial-in، و عبر الإنترنت SIP",
    "Enable phone and SIP dial-in" : "تمكين الاتصال الهاتفي dial-in، و عبر الإنترنت SIP",
    "Allow to dial-in without a PIN" : "السماح بالاتصال بدون رقم التعريف الشخصي PIN",
    "Join" : "إن",
    "Error while creating the conversation" : "حدث خطأ اثناء نسخ رابط المحادثة",
    "Create a new conversation" : "إنشاء محادثة جديدة",
    "Join open conversations" : "الانضمام إلى محادثات جارية",
    "Call a phone number" : "اتَّصِل برقم هاتف",
    "Unread mentions" : "إشارات غير مقروءة",
    "Create conversation" : "انشاء محادثة",
    "Enter your name" : "أدخِل اسمك",
    "Submit name and join" : "أرسِل الاسم و انضَمّ",
    "Do you already have an account?" : "هل لديك حساب سلفاً؟",
    "Log in" : "تسجيل الدخول",
    "Error while verifying uploaded file" : "خطأ أثناء التحقق من الملف المرفوع",
    "Uploaded file is verified" : "تمّ التحقق من الملف المرفوع",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "تنسيق المحتوى عبارة عن قيم مفصولة بفاصلة (CSV) :<br/>-  سطر الترويسة لازم ويجب أن يكون مُطابقاً <samp> الاسم، \"الإيميل\"</samp> أو فقط <samp>\"الإيميل\"\"</samp><br/>- إدخالية واحدة فقط لكل سطر (مثل: <samp>\"John Doe\",\"john@example.tld\"</samp>)",
    "Participants added successfully" : "تمّت إضافة المشاركين بنجاحٍ",
    "Error while adding participants" : "خطأ أثناء إضافة المشاركين",
    "Import a file" : "إستيراد ملف",
    "Browse" : "تصفُّح",
    "Verifying uploaded file …" : "التحقُّق من الملفات المرفوعة جارٍ ...",
    "This might take a moment" : "يمكن أن يستغرق هذا لحظات ...",
    "Send invitations" : "إرسال دعوات",
    "_%n invalid email_::_%n invalid emails_" : ["%n إيميل غير صحيح","%n إيميل غير صحيح","%n إيميل غير صحيح","%n إيميلات غير صحيحة","%n إيميل غير صحيح","%n إيميل غير صحيح"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["%n  إيميل سبق استيراده أو هو مكرر","%n  إيميل سبق استيراده أو هو مكرر","%n  إيميل سبق استيراده أو هو مكرر","%n  إيميلات سبق استيرادها أو هي مكررة","%n  إيميل سبق استيراده أو هو مكرر","%n إيميل سبق استيراده أو هو مكرر"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["%n دعوة يمكن إرسالها","%n دعوة يمكن إرسالها","%n دعوة يمكن إرسالها","%n دعوة يمكن إرسالها","%n دعوات يمكن إرسالها","%n دعوة يمكن إرسالها"],
    "An error occurred while calling a phone number" : "حدث خطأ أثناء الاتصال برقم هاتف",
    "Phone number could not be called: {error}" : "تعذّر طلب الاتصال برقم الهاتف: {error}",
    "Phone number could not be called" : "تعذّر الاتصال برقم الهاتف",
    "Search participants or phone numbers" : "البحث عن مشاركين أو أرقام هواتف",
    "Creating the conversation …" : "إنشاء محادثة ...",
    "Mark as read" : "تحديد كمقروء ",
    "Mark as unread" : "تحديد كغير مقروء ",
    "Remove from favorites" : "إزالتها مِن المفضلة",
    "Add to favorites" : "أضفه إلى المفضلة",
    "Unarchive conversation" : "استرجاع المحادثة من الأرشيف",
    "You need to promote a new moderator before you can leave the conversation." : "يجب عليك ترقية مشرف لاحد المشاركين قبل مغادرة المحادثة.",
    "New tag" : "وسم جديد",
    "Tag name" : "اسم الوسم",
    "Conversation actions" : "إجراءات المحادثة ",
    "Tags" : "الوسوم",
    "Notify about calls" : "إشعار بالمكالمات",
    "Rename tag" : "غَيِّر اسم الوَسْم",
    "Delete tag" : "حذف الوسم",
    "Move up" : "نقلٌ للأعلي",
    "Move down" : "نقلٌ للأسفل",
    "Pending invitations" : "دعوات معلقة",
    "From {user} at {remoteServer}" : "من {user} على الخادم {remoteServer}",
    "Decline invitation" : "رفض الدعوة",
    "Accept invitation" : "قبول الدعوة",
    "No pending invitations" : "لا توجد دعوات معلقة",
    "Home" : "الرئيسية",
    "Unread" : "غير مقروء",
    "Alphabetically" : "أبجديا",
    "No matches found" : "لم يٌمكن إيجاد أي تطابقات",
    "No conversations found" : "لم يتم العثور على المحادثات ",
    "You have no archived conversations." : "ليس لديك أي محادثات مؤرشفة.",
    "You have no unread mentions." : "لا توجد لديك أي إشارات غير مقرؤة.",
    "You have no unread messages." : "لا توجد لديك أي رسائل غير مقرؤة.",
    "An error occurred while performing the search" : "حدث خطأ اثناء البحث",
    "Conversation list" : "قائمة المحادثة ",
    "Unread messages" : "رسائل غير مقروءة",
    "Clear filters" : "إزالة التصفية",
    "New personal note" : "ملاحظة شخصية جديدة",
    "Back to conversations" : "عودة إلى المحادثات",
    "Archived conversations" : "المحادثات المؤرشفة",
    "Clear filter" : "إزالة التصفية",
    "App settings" : "إعدادات التطبيق",
    "Users" : "المستخدمين:",
    "Groups" : "المجموعات",
    "Teams" : "الفرق",
    "Federated users" : "مستخدِمون من السحابة الموحدة",
    "New private conversation" : "محادثة جديدة على الخاص",
    "Other sources" : "مصادر آخرى",
    "Open conversations" : "فتح المحادثات ",
    "No search results" : "لا توجد نتائج",
    "Users, groups and teams" : "المستخدمين، والمجموعات، والفرق",
    "Users and groups" : "الاعضاء والمجموعات",
    "Users and teams" : "المستخدمين و الفرق",
    "Groups and teams" : "المجموعات والفرق",
    "New group conversation" : "محادثة جماعية جديدة",
    "The meeting will start soon" : "هذا الاجتماع سيبدأ قريباً",
    "This meeting is scheduled for {startTime}" : "تمت جدولة هذا الاجتماع في {startTime}",
    "You are currently waiting in the lobby" : "أنت حاليا في انتظار الاستقبال",
    "Advanced" : "متقدمة",
    "Select microphone" : "اختر مايك",
    "No microphone available" : "لا يوجد مايكرفون متاح",
    "Select speaker" : "حدِّد المُتحَدِّث",
    "No speaker available" : "لايوجد أيّ مُتحَدِّث",
    "Select camera" : "اختر كاميرا",
    "No camera available" : "لا توجد كاميرا متاحة",
    "Select a device" : "إختَر جهازاً",
    "Playing …" : "قيد التشغيل ...",
    "Test speakers" : "اختبار مكبرات الصوت",
    "Test" : "اختبار",
    "Devices" : "الأجهزة",
    "Backgrounds" : "الخلفيّات",
    "No audio" : "بدون صوت",
    "No camera" : "بدون كاميرا",
    "Display video as you will see it (mirrored)" : "عرض الفيديو كما ستراه أنت (معكوساً)",
    "Display video as others will see it" : "عرض الفيديو كما سيراه الآخرون",
    "Calls are not supported in your browser" : "المكالمات غير مدعومة في متصفحك",
    "Access to microphone is only possible with HTTPS" : "الوصول إلى المايكرفون مسموح فقط في HTTPS",
    "Access to microphone was denied" : "تم رفض الوصول للمايكرفون",
    "Error while accessing microphone" : "حدث خطأ اثناء الوصول إلى المايكرفون",
    "Access to camera is only possible with HTTPS" : "الوصول للكاميرا مسموح فقط في HTTPS",
    "The call is being recorded." : "يتم تسجيل المكالمة.",
    "The call might be recorded." : "المكالمة يُمكن أن يتم تسجيلها.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "يمكن أن يشمل التسجيل صوتك، و مقاطع الفيديو من الكاميرات، و شاشات مُشارَكة. إذنُك مطلوبٌ قبل الانضمام إلى المكالمة.",
    "Give consent to the recording of this call" : "إمنَحِ الإذن بتسجيل هذه المكالمة",
    "Start recording immediately with the call" : "إبدأ التسجيل فور بدء المكالمة",
    "Apply settings" : "طبِّق الإعدادات",
    "Select virtual office background" : "اختر الخلفية الافتراضية للمكتب",
    "Select virtual home background" : "اختر الخلفية الافتراضية للمنزل",
    "Select virtual abstract background" : "اختر الخلفية الافتراضية للملخص",
    "Select virtual beach background" : "اختر الخلفية الافتراضية للشاطئ",
    "Select virtual park background" : "اختر الخلفية الافتراضية للمنتزه",
    "Select virtual theater background" : "اختر الخلفية الافتراضية للمسرح",
    "Select virtual library background" : "اختر الخلفية الافتراضية للمكتبة",
    "Select virtual space station background" : "اختر الخلفية الافتراضية لمساحة محطة المستخدم",
    "Error while uploading the file" : "خطأ أثناء رفع الملف",
    "Select a file" : "إختَر ملفّاً",
    "Invalid path selected" : "تم تحديد مسار غير صحيح",
    "Select virtual background from file {fileName}" : "اختر الخلفية الافتراضية من الملف {fileName}",
    "Blur" : "تضبيب",
    "Upload" : "تحميل",
    "Files" : "الملفات",
    "(editing)" : "(تعديل)",
    "(edited)" : "(معدّلة)",
    "The message has expired or has been deleted" : "الرسالة انتهت صلاحيتها أو سبق حذفها",
    "Cancel quote" : "إلغاء التعليق",
    "24 hours" : "24 ساعة",
    "7 days" : "7 أيام",
    "Clear reminder – {timeLocale}" : "إمحُ التذكير – {timeLocale}",
    "Edited by {actor}" : "تمّ تحريرها من قِبَل {actor}",
    "Message text copied to clipboard" : "تمّ نسخ الرسالة النصّية إلى الحافظة",
    "Message text could not be copied" : "تعذّر نسخ الرسالة النصّية إلى الحافظة",
    "Message forwarded to \"Note to self\"" : "الرسالة أُعِيدَ توجيهها إلى \"ملاحظة لنفسي\"",
    "Error while forwarding message to \"Note to self\"" : "حدث خطأ أثناء إعادة توجيه الرسالة إلى \"ملاحظة لنفسي\"",
    "A reminder was successfully removed" : "تمّ بنجاح حذف التذكير",
    "Error occurred when removing a reminder" : "حدث خطأ أثناء حذف التذكير",
    "A reminder was successfully set at {datetime}" : "تمّ بنجاح تعيين التذكير إلى {datetime}",
    "Error occurred when creating a reminder" : "حدث خطأ أثناء إنشاء التذكير",
    "Add a reaction to this message" : "إضافة تفاعل على هذه الرسالة",
    "Reply" : "رد",
    "More actions" : "إجراءات إضافية",
    "Set reminder" : "ضبط التذكير",
    "Reply privately" : "الرد على الخاص",
    "Edit message" : "تحرير رسالة",
    "Copy message" : "نسخ الرسالة",
    "Copy message link" : "نسخ رابط الرسالة ",
    "Go to file" : "الذهاب إلى ملف",
    "Download file" : "تنزيل ملف",
    "Forward message" : "رسالة معاد توجيهها",
    "Translate" : "ترجم",
    "Set custom reminder" : "تعيين تذكير مخصص",
    "Close reactions menu" : "إغلاق قائمة التفاعل",
    "React with {emoji}" : "تفاعل باستخدام {emoji}",
    "React with another emoji" : "تفاعل مع رمز تعبيري آخر",
    "Choose a conversation to forward the selected message." : "اختر محادثة لإعادة توجيه الرسالة المحددة إليها.",
    "Error while forwarding message" : "خطأ أثناء إعادة توجيه الرسالة",
    "The message has been forwarded to {selectedConversationName}" : "تمت إعادة توجيه الرسالة إلى {selectedConversationName}",
    "Dismiss" : "الغاء",
    "Go to conversation" : "ذهاب إلى المحادثة",
    "Detect language" : "إكتشف اللغة",
    "The message could not be translated" : "لا يمكن ترجمة الرسالة",
    "Translation copied to clipboard" : "تمّ نسخ الترجمة إلى الحافظة",
    "Translation could not be copied" : "تعذّر نسخ الترجمة",
    "Translate message" : "ترجِم الرسالة",
    "Source language to translate from" : "اللغة الأصلية التي ستتم الترجمة منها",
    "Translate from" : "ترجِم من",
    "Target language to translate into" : "اللغة الهدف التي ستتم الترجمة إليها",
    "Translate to" : "ترجِم إلى",
    "Translating" : "يترجم",
    "Copy translated text" : "نسخ النص المترجم",
    "Send now" : "أرسِل الآن",
    "Message read by everyone who shares their reading status" : "تمت قراءة الرسالة من قبل كل من يشاركهم الحالة ",
    "Message sent" : "تم إرسال الرسالة ",
    "Sent without notification" : "تمّ الإرسال بدون إشعار",
    "Deleting message" : "حذف الرسالة",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "تم حذف الرسالة بنجاح، ولكن تم تكوين بُريْمِج bot أو جسر Matterbridge و لربما تمّ توزيع الرسالة بالفعل على خدمات أخرى",
    "Message deleted successfully" : "تم مسح الرسالة بنجاح",
    "Message could not be deleted because it is too old" : "تعذر مسح الرسالة لإنها قديمة جدًا",
    "Only normal chat messages can be deleted" : "يمكن حذف رسائل الدردشة العادية فقط",
    "An error occurred while deleting the message" : "حدث خطأ أثناء حذف الرسالة",
    "Your browser does not support playing audio files" : "متصفحك لا يدعم تشغيل ملفات الصوت",
    "Contact" : "التواصل",
    "{stack} in {board}" : "{stack} في  {board}",
    "Deck Card" : "بطاقة Deck",
    "Remove {fileName}" : "إزالة {fileName}",
    "Open this location in OpenStreetMap" : "افتح هذا الموقع في تطبيق OpenStreetMap",
    "Sending message" : "إرسال الرسالة ",
    "Failed to send the message. Click to try again" : "فشل في إرسال الرسالة، انقر للمحاولة مجددًا ",
    "Not enough free space to upload file" : "لا يوجد مساحة تخزينية كافية لرفع الملف ",
    "You cannot send messages to this conversation at the moment" : "لا يمكنك إرسال الرسائل لهذه المحادثة حاليًا ",
    "Could not update the message" : "تعذّر تحديث الرسالة",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["مسودة الاستبيان • %n خيارات","مسودة الاستبيان • %n خيار","مسودة الاستبيان • %n خيارات","مسودة الاستبيان • %n خيارات","مسودة الاستبيان • %n خيارات","مسودة الاستبيان • %n خيارات"],
    "_%n vote_::_%n votes_" : ["%n أصوات","%n صوت","%n أصوات","%n أصوات","%n أصوات","%n أصوات"],
    "Edit poll draft" : "تحرير مُسوَّدة التصويت",
    "Delete poll draft" : "حذف مسودة الاستبيان",
    "Open poll" : "فتح استطلاع",
    "See results" : "رؤية النتائج",
    "Reactions" : "التفاعلات",
    "No permission to post reactions in this conversation" : "لا يوجد إذن لنشر التفاعلات في هذه المحادثة",
    "and {participant}" : "و {participant}",
    "_and %n other participant_::_and %n other participants_" : ["و %n مشارك آخر","و %n مشارك آخر","و %n مُشاركين آخرين","و %n مُشاركين آخرين","و %n مشاركين آخرين","و %n مشاركين آخرين"],
    "Show all reactions" : "أظهِر جميع التفاعلات",
    "Add more reactions" : "إضافة تفاعلاتٍ أخرى",
    "Show or collapse system messages" : "إظهار أو طي رسائل النظام",
    "No messages" : "لاتوجد رسائل",
    "All messages have expired or have been deleted." : "كل الرسائل انتهت صلاحيتها أو تمّ حذفها",
    "Unpin" : "فك التثبيت",
    "Cancel search" : "إلغاء البحث",
    "Add a phone number" : "إضافة رقم هاتف",
    "Error: A password is required to create the conversation." : "خطأ: كلمة المرور لازمة لإنشاء المحادثة.",
    "All set, the conversation \"{conversationName}\" was created." : "تمّ إنشاء المحادثة \"{conversationName}\" بنجاح.",
    "Create a new group conversation" : "انشاء محادثة جماعية جديدة",
    "Add participants" : "اضافة مشارك جديد",
    "Maximum length exceeded ({maxlength} characters)" : "تمّ تجاوز الحدّ الأقصى ({maxlength} حرفاً)",
    "Conversation visibility" : "رؤية المحادثة",
    "Allow guests to join via link" : "السماح بالضيوف بالانضمام عن طريق الرابط",
    "Enter password" : "أدخل كلمة المرور",
    "This conversation has been locked" : "هذه المحادثة مغلقة",
    "No permission to post messages in this conversation" : "ليس لديك صلاحية لنشر رسائل في هذه المحادثة",
    "Joining conversation …" : "جارٍ الانضمام للمحادثة ",
    "Write a message without notification" : "أكتُب رسالة بدون إشعارٍ",
    "Send message silently" : "إرسال رسالة صامتة",
    "Send message" : "أرسل رسالة",
    "Send without notification" : "أرسِل بدون إشعار",
    "The participant will not be notified about new messages" : "سوف لن يتم إشعار المشارك بشأن الرسائل الجديدة",
    "Participants will not be notified about new messages" : "سوف لن يتم إشعار المُشاركين بشأن الرسائل الجديدة",
    "The message could not be edited" : "تعذّر تحرير الرسالة",
    "File to share" : "ملف للمشاركة",
    "File upload is not available in this conversation" : "رفع الملفات غير متاح في هذه الدردشة",
    "Add emoji" : "اضافة رمز تعبيري",
    "Adding a mention will only notify users who did not read the message." : "إضافة إشارة ستؤدي إلى إشعار المستخدِمين الذين لم يسبق لهم قراءة الرسالة.",
    "Send later" : "أرسِل لاحقاً",
    "Cancel editing" : "إلغاء التحرير",
    "{user} is out of office and might not respond." : "{user} خارج المكتب الآن، و يمكن ألّا يستجيب",
    "Absence period: {startDate} - {endDate}" : "فترة الغياب: {startDate} - {endDate}",
    "Replacement:" : "البديل:",
    "Share from {nextcloud}" : "مشاركة من {nextcloud}",
    "Share from Files" : "مشاركة من الملفات",
    "Share files to the conversation" : "مشاركة ملفات في المحادثة",
    "Upload from device" : "إرفع من جهاز",
    "Create new poll" : "إنشاء استطلاع جديد",
    "Smart picker" : "اللاقط الذكي Smart picker",
    "Record voice message" : "تسجيل رسالة صوتية",
    "End recording and send" : "إنهاء التسجيل والإرسال",
    "Dismiss recording" : "رفض التسجيل",
    "Access to the microphone was denied" : "تم رفض الوصول إلى الميكروفون",
    "Microphone either not available or disabled in settings" : "الميكروفون إما غير متاح أو تم تعطيله من الإعدادات",
    "Error while recording audio" : "خطأ أثناء تسجيل الصوت",
    "Generating summary of unread messages …" : "توليد ملخص للرسائل غير المقرؤة ...",
    "Summary is AI generated and might contain mistakes" : "المُلخَّص يتم توليده بالذكاء الاصطناعي و يمكن أن يحتوي على أخطاء",
    "Error occurred during a summary generation" : "حدث خطأ أثناء توليد المُلخَّص",
    "New file" : "ملف جديد",
    "Blank" : "فارغ",
    "Error while creating file" : "خطأ أثناء إنشاء الملف",
    "Create and share a new file" : "إنشاء ملف جديد ومشاركته",
    "Name of the new file" : "اسم الملف الجديد",
    "Create file" : "إنشاء ملف",
    "Someone is typing …" : "شخصٌ ما يكتبُ ...",
    "{user1} is typing …" : "{user1} يكتُب…",
    "{user1} and {user2} are typing …" : "{user1} و {user2} يكتُبُون …",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} و {user3} يكتُبُون …",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2} و {user3} و%n أخرون يكتُبُون …","{user1}, {user2} و {user3} و%n آخر يكتُب …","{user1}, {user2} و {user3} و%nأخرون يكتُبُون …","{user1}, {user2} و {user3} و%n أخرون يكتُبُون …","{user1}, {user2} و {user3} و %n أخرون يكتُبُون …","{user1}, {user2} و {user3} و%n أخرون يكتُبُون …"],
    "Add more files" : "اضافة المزيد من الملفات",
    "Send" : "أرسل",
    "In this conversation <strong>{user}</strong> can:" : "في هذه المحادثة يستطيع<strong> {user}</strong>:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "تحرير الأذونات الافتراضية للمشاركين في <strong>{conversationName}</strong>",
    "Start a call" : "بدء المكالمة",
    "Skip the lobby" : "تخطي انتظار القبول",
    "Can post messages and reactions" : "يمكن نشر الرسائل والتفاعلات",
    "Enable the microphone" : "تفعيل الميكروفون",
    "Enable the camera" : "تمكين الكاميرا",
    "Share the screen" : "شارك الشاشة",
    "Update permissions" : "تحديث الأذونات",
    "Updating permissions" : "الرجاء الاتصال بالمسؤول الخاص بك.",
    "No poll drafts" : "لا توجد أي مسودات للاستبيان",
    "There is no poll drafts yet saved for this conversation" : "لا توجد أي مسودات محفوظة للاستبيان في هذه المحادثة",
    "Create poll in {name}" : "إنشاء تصويت في {name}",
    "Create poll" : "صَوّت، رجاءً",
    "Error while importing poll" : "خطأ أثناء استيراد الاستبيان",
    "Question" : "سؤال",
    "Ask a question" : "طرح سؤال",
    "Import draft from file" : "إستيراد مسودة من ملف",
    "Answers" : "الإجابات",
    "Answer {option}" : "إجابة {option}",
    "Delete poll option" : "حذِف خيار التصويت",
    "Add answer" : "إضافة إجابة",
    "Settings" : "الإعدادات",
    "Anonymous poll" : "استبيان مع إخفاء هوية المصوتين",
    "Multiple answers" : "إجابات متعددة",
    "Save as draft" : "إحفَظ كمسودة",
    "Export draft to file" : "تصدير مسودة إلى ملف",
    "You voted for this option" : "أنت صوَّتَّ على هذا الخيار",
    "End poll" : "نهاية التصويت",
    "Change your vote" : "تغيير صوتك",
    "Results" : "النتائج ",
    "Voted participants" : "المُشارِكون المُصَوِّتُون",
    "Send a message to \"{roomName}\"" : "إرسال رسالة إلى \"{roomName}\"",
    "Hide list of participants" : "إخفاء قائمة المشاركين",
    "Show list of participants" : "عرض قائمة المشاركين",
    "Assistance requested in {roomName}" : "تمّ طلب مساعدة في {roomName}",
    "The message was sent to \"{roomName}\"" : "تم إرسال الرسالة إلى \"{roomName}\"",
    "Dismiss request for assistance" : "رفض طلب المساعدة",
    "Send message to room" : "إرسال رسالة إلى الغرفة",
    "Back to main room" : "عودة إلى الغرفة الرئيسية",
    "Back to your room" : "الرجوع إلى غرفتك",
    "Message all rooms" : "أدِر كل الغرف",
    "Start session" : "إبدَإِ الجلسة",
    "Start a call before you start a breakout room session" : "إبدأ مكالمة قبل بدأ جلسةً الغرفة الجانبية",
    "Stop session" : "أوقِف الجلسة",
    "The message was sent to all breakout rooms" : "تمّ إرسال الرسالة إلى كل الغُرف الجانبية breakout rooms",
    "Send a message to all breakout rooms" : "إرسال رسالة إلى جميع الغرف الجانبية",
    "Breakout rooms are not started" : "الغرف الجانبية لم تبدأ ",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : " المكالمات بدون استعمال خلفية للأداء العالي تتسبب في إشكاليات في الاتصال و حمل زائد على الأجهزة. {linkstart}تعلَّم المزيد {linkend}",
    "Talk setup incomplete" : "إعدادات \"المحادثة\" Talk لم تكتمل",
    "Disable lobby" : "تعطيل ساحة الإنتظار",
    "Settings for participant \"{user}\"" : "إعدادات المشارك \"{المستخدم}\"",
    "Participant \"{user}\"" : "المشارك \"{user}\"",
    "moderator" : "مشرف",
    "bot" : "بوت",
    "guest" : "ضيف",
    "Ringing …" : "يَرِنُّ الآن ...",
    "Call rejected" : "تمّ رفض المكالمة",
    "{time} talking …" : "{time} في محادثة …",
    "{time} talking time" : "{time} زمن المحادثة",
    "Raised their hand" : "رفعوا أيديهم",
    "Joined with video" : "انضم مع مشاركة بالفيديو",
    "Joined via phone" : "انضم عبر الجوال ",
    "Joined with audio" : "انضم مع مشاركة بالصوت ",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "يجب أن يكون عدد حروف النص أقل من أو يساوي {maxLength} . الطول الحالي للنص هو {charactersCount} حرفاً.",
    "Remove group and members" : "حذف المجموعة والأعضاء ",
    "Remove team and members" : "إزالة الفريق و الأعضاء",
    "Remove participant" : "حذف مشارك",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "هل تريد حقًا إزالة المجموعة \"{displayName}\" وأعضائها من هذه المحادثة؟",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "هل تريد حقًا إزالة الفريق \"{displayName}\" وأعضائه من هذه المحادثة؟",
    "Do you really want to remove {displayName} from this conversation?" : "هل تريد حقًا إزالة {displayName} من هذه المحادثة؟",
    "Notification was sent to {displayName}" : "تمّ إرسال الإخطار إلى {displayName}",
    "Could not send notification to {displayName}" : "تعذر إرسال إشعار إلى {displayName}",
    "Permissions granted to {displayName}" : "تم منح الأذونات لـ {displayName}",
    "Could not modify permissions for {displayName}" : "تعذر تعديل الأذونات لـ {displayName}",
    "Permissions removed for {displayName}" : "تمت إزالة الأذونات لـ {displayName}",
    "Permissions set to default for {displayName}" : "تم تعيين الأذونات على الإعداد الافتراضي لـ {displayName}",
    "Phone number could not be hung up" : "رقم الهاتف لا يمكن قفله",
    "Phone number could not be put on hold" : "رقم الهاتف لا يمكن تعليقه",
    "Phone number could not be muted" : "رقم الهاتف لا يمكن كتمه",
    "Phone number could not be unmuted" : "رقم الهاتف لا يمكن إلغاء كتمه",
    "DTMF message could not be sent" : "تعذّر إرسال رسالة DTMF - النغمة المزدوجة متعددة الترددات-",
    "Phone number copied to clipboard" : "تمّ نسخ رقم الهاتف إلى الحافظة",
    "Phone number could not be copied" : "تعذّر نسخ رقم الهاتف إلى الحافظة",
    "in the lobby" : "في صالة الانتظار",
    "Dial out phone" : "أطلُب اتصال هاتفي",
    "Hang up phone" : "علِّق الاتصال الهاتفي",
    "Move back to lobby" : "عودة إلى صالة الانتظار",
    "Move to conversation" : "إنتقال إلى المحادثة",
    "Dial-in PIN" : "رمز الإتصال الهاتفي ",
    "Demote from moderator" : "تخفيض رتبة مشرف",
    "Promote to moderator" : "ترقية لـ مشرف",
    "Resend invitation" : "إعادة إرسال الدعوة",
    "Send call notification" : "إرسال إشعار المكالمة",
    "Dial out phone number" : "أطلُب الاتصال برقم هاتفٍ",
    "Resume call for phone number" : "استئناف المكالمة مع رقم هاتف",
    "Put phone number on hold" : "ضع رقم هاتف في وضع الانتظار",
    "Unmute phone number" : "إلغاء كتم صوت رقم هاتف",
    "Mute phone number" : "كتم صوت رقم هاتف",
    "Copy phone number" : "نسخ رقم هاتف",
    "Reset custom permissions" : "إعادة إعداد الأذونات المخصصة",
    "Grant all permissions" : "منح كافة الأذونات",
    "Remove all permissions" : "إزالة كافة الأذونات",
    "Also ban from this conversation" : "محظور أيضاً في هذه المحادثة",
    "Internal note (reason to ban)" : "ملاحظة داخلية (سبب الحظر)",
    "Remove" : "حذف",
    "Permissions modified for {displayName}" : "تم تعديل الأذونات لـ {displayName}",
    "Add users, groups or teams" : "إضافة مستخدمين، و مجموعات، وفرق",
    "Add users or groups" : "اضافة اعضاء او مجموعات",
    "Add users or teams" : "إضافة مستخدمين أو فرق",
    "Add users" : "اضافة اعضاء",
    "Add groups or teams" : "إضافة مجموعات وفرق",
    "Add groups" : "اضافة مجموعات",
    "Add teams" : "إضافة فرق",
    "Add other sources" : "اضافة مصدر آخر",
    "Add emails" : "اضافة عبر البريد",
    "Integrations" : "مُكاملات",
    "Add federated users" : "إضافة المستخدمين الخارجيين",
    "Searching …" : "جاري البحث…",
    "Search for more users" : "البحث عن مزيد من الاعضاء",
    "You can search or add participants via name, email, or Federated Cloud ID" : "بمكنك البحث عن او اضافة مشاركين بدلالة الاسم أو الايميل أو معرف السحابة الموحدة",
    "Search or add participants" : "بحث او اضافة مشاركين",
    "Invitation was sent to {actorId}" : "تمّ إرسال الدعوة إلى {actId}",
    "An error occurred while adding the participants" : "حدث خطأ اثناء إضافة المشاركين",
    "Participants" : "المشاركون",
    "Participants ({count})" : "المشاركون ({count})",
    "Open chat" : "دردشة مفتوحة",
    "You have new unread messages in the chat." : "لديك رسائل جديدة غير مقروءة فى الدردشة.",
    "You have been mentioned in the chat." : "أشار إليك أحدهم في الدردشة",
    "Search messages" : "البحث في الرسائل",
    "Chat" : "الدردشة",
    "Details" : "التفاصيل",
    "Shared items" : "عناصر مُشارَكة",
    "Search in {name}" : "البحث في {name}",
    "Search messages …" : "البحث في الرسائل ...",
    "Search options" : "خيارات البحث",
    "From User" : "من مُستخدِم",
    "Since" : "منذ",
    "Until" : "حتى",
    "No results found" : "لا توجد أي نتائج",
    "Load more results" : "تحميل المزيد من النتائج",
    "Projects" : "المشاريع",
    "No shared items" : "لا توجد عناصر مشاركة",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "الربط لمحادثة",
    "No open conversations found" : "لا توجد أي محادثات مفتوحة",
    "Either there are no open conversations or you joined all of them." : "إمّا أنه لا توجد أيّ محادثات جارية أو أنك مُنضَمٌّ سلفاً إليها جميعاَ",
    "Check spelling or use complete words." : "تحقَّق من الهجاء أو استخدام كلماتٍ كاملة",
    "Search conversations or users" : "البحث عن المحادثات او الاعضاء",
    "Select conversation" : "اختر محادثة",
    "Number length is not valid" : "عدد خانات الرقم غير صحيح",
    "Region code is not valid" : "كود المنطقة أو الدولة غير صحيح",
    "Number length is too short" : "عدد خانات الرقم أقل مما يُفترَض",
    "Number length is too long" : "عدد خانات الرقم أكثر مما يُفتَرض",
    "Number is not valid" : "الرقم غير صحيح",
    "Phone numbers" : "أرقام الهواتف",
    "Display name: {name}" : "اسم العرض: {name}",
    "Edit display name" : "عَدِّل اسم العرض",
    "Save name" : "حفظ الاسم",
    "Error while setting personal setting" : "خطأ أثناء إعداد الاعدادات الشخصية",
    "Error while saving sounds setting" : "حدث خطأ أثناء حفظ إعدادات الأصوات ",
    "Play sounds when participants join or leave a call" : "تشغيل الأصوات عندما انضمام أو مغادرة المشاركون المكالمة",
    "Notification settings" : "إعدادات الإشعارات",
    "Default language" : "اللغة الافتراضية",
    "Select location for attachments" : "اختر مكان المرفقات",
    "Error while setting attachment folder" : "خطأ اثناء تحديد مجلد المرفقات",
    "Error while setting read status privacy" : "حدث خطأ عند تعيين خصوصية قراءة الرسائل ",
    "Error while setting typing status privacy" : "خطأ أثناء تعيين خصوصية حالة الكتابة",
    "Error while setting default media state" : "حدث خطأ أثناء حفظ حالة الوسائط ",
    "Privacy" : "الخصوصية",
    "Attachments folder" : "مجلد المرفقات",
    "Toggle full screen" : "تبديل إلى ملء الشاشة",
    "Search" : "البحث",
    "Focus the chat input" : "تركيز على إدخال الدردشة",
    "Unfocus the chat input to use shortcuts" : "الغاء تركيز على إدخال الدردشة",
    "Edit your last message" : "قّم بتحرير رسالتك الأخيرة",
    "Shortcuts while in a call" : "اختصارات اثناء مكالمة",
    "Camera on and off" : "تشغيل وإيقاف تشغيل الكاميرا ",
    "Microphone on and off" : "تفعيل او تعطيل المايك",
    "Raise or lower hand" : "رفع أو خفض اليد ",
    "Push to talk or push to mute" : "اضغط للتحدث او اضغط لكتم الصوت",
    "Zoom-in / zoom-out a screen share" : "تكبير/تصغير شاشة مُشارَكة",
    "Mouse wheel" : "عجلة الفارة",
    "Start call silently" : "بدء اتصال صامت",
    "Start call" : "ابدء مكالمة",
    "End call" : "إقطَع المكالمة",
    "This call has just ended" : "المكالمة انتهت للتّو",
    "You will be able to join the call only after a moderator starts it." : "لن تتمكن من الانضمام إلى المكالمة إلا بعد أن يبدأها المشرف.",
    "End call for everyone" : "إنهاء المكالمة للجميع",
    "Starting the recording" : "بدء التسجيل",
    "Recording" : "تسجيل",
    "The call has been running for one hour." : "المكالمة ما زالت مستمرة منذ حوالي الساعة.",
    "Cancel recording start" : "إلغاء مباشرة التسجيل",
    "Stop recording" : "إيقاف التسجيل",
    "Raise hand" : "رفع اليد",
    "Raise hand (R)" : "رفع اليد (r)",
    "Lower hand" : "خفض اليد ",
    "Lower hand (R)" : "خفض اليد (R)",
    "Send a reaction" : "إرسال تفاعل",
    "React with {reaction}" : "تَفَاعَل مع {reaction}",
    "All tasks done!" : "تمّ إنجاز جميع المهام!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} من %n مهمة","{done} من %n مهمة","{done} من %n مهمة","{done} من %n مهام","{done} من %n مهمة","{done} من %n مهمة"],
    "_%n participant in call_::_%n participants in call_" : ["%n مشاركين بالمكالمة","%n مشارك بالمكالمة","%n مشاركين بالمكالمة","%n مشاركين بالمكالمة","%n مشاركين بالمكالمة","%n مشاركين بالمكالمة"],
    "You are not allowed to enable screensharing" : "غير مسموح لك بتمكين مشاركة الشاشة",
    "No screensharing" : "عدم مشاركة الشاشة",
    "Screensharing options" : "خيارات مشاركة الشاشة",
    "Enable screensharing" : "تفعيل مشاركة الشاشة",
    "Bad sent video and screen quality." : "الفيديو المرسل وجودة الشاشة ضعيفة.",
    "Bad sent screen quality." : "جودة الشاشة المرسلة ضعيفة.",
    "Bad sent video quality." : "جودة الفيديو المرسل ضعيفة.",
    "Bad sent audio, video and screen quality." : "الصوت والفيديو المرسل وجودة الشاشة ضعيفة.",
    "Bad sent audio and screen quality." : "الصوت المرسل وجودة الشاشة ضعيفة.",
    "Bad sent audio and video quality." : "الصوت المرسل وجودة الفيديو ضعيفة.",
    "Bad sent audio quality." : "جودة الصوت المرسل ضعيفة.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "اتصالك بالإنترنت ضعيف وقد لا يتمكن المشاركون الآخرون من رؤية شاشتك. لتحسين الوضع، حاول تعطيل تشويش الخلفية أو تعطيل الفيديو الخاص بك أثناء قيامك بمشاركة الشاشة.",
    "Disable background blur" : "تعطيل طمس وتشويش الخلفية",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "اتصالك بالإنترنت ضعيف وقد لا يتمكن المشاركون الآخرون من رؤية شاشتك. لتحسين الوضع، حاول تعطيل الفيديو الخاص بك أثناء مشاركة الشاشة.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "اتصالك بالانترنت او جهازك الخاص قد يؤثر ذلك على عدم ظهور شاشتك للآخرين.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "اتصالك بالانترنت او جهازك الخاص قد يؤثر ذلك على عدم ظهورك للآخرين.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "اتصالك بالإنترنت ضعيف بشكل قد لا يتمكن معه المشاركون الآخرون من رؤيتك. لتحسين الوضع، حاول تعطيل تشويش الخلفية أو تعطيل الفيديو الخاص بك أثناء قيامك بمشاركة الشاشة.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "اتصالك بالانترنت او جهازك الخاص قد يؤثر ذلك على عدم ظهورك للآخرين وفهم المشاركين. لتحسين ذلك جرب تعطيل الفيديو في حال مشاركة الشاشة.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "اتصالك بالانترنت ضعيف بشكل قد يؤثر على ظهورك للآخرين. لتحسين ذلك، جرب تعطيل مشاركة الشاشة.",
    "Disable screenshare" : "تعطيل مشاركة الشاشة",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "اتصالك بالإنترنت ضعيف بشكل قد لا يتمكن المشاركون معه الآخرون من رؤيتك. لتحسين الوضع، حاول تعطيل تشويش الخلفية أو تعطيل الفيديو الخاص بك.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "اتصالك بالانترنت او جهازك الخاص قد يؤثر ذلك على فهم المشاركين وعدم ظهورك للآخرين. لتحسين ذلك جرب تعطيل الفيديو.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "اتصالك بالانترنت او جهازك الخاص قد يؤثر ذلك فهم الآخرين.",
    "Screen sharing is not supported by your browser." : "مشاركة الشاشة غير مدعوم من قبل متصفحك.",
    "Screen sharing requires the page to be loaded through HTTPS." : "مشاركة الشاشة يتطلب تحميل الصفحة عن طريق HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "مشاركة الشاشة يتطلب تحميل الصفحة عن طريق HTTPS.",
    "An error occurred while starting screensharing." : "حدث خطأ اثناء محاولة مشاركة الشاشة.",
    "Show your screen" : "مشاركة الشاشة",
    "Stop screensharing" : "التوقف عن مشاركة الشاشة",
    "Mute others" : "كتم صوت الآخرين",
    "Start recording" : "بدء التسجيل",
    "Set up breakout rooms" : "جَهِّز الغرف الجانبية",
    "Download attendance list" : "تنزيل قائمة الحضور",
    "Open Calendar" : "إفتَح التقويم",
    "Remove participant {name}" : "إزالة المشارك {name}",
    "Keep" : "حفظ",
    "Open dialpad" : "فتح لوحة طلب الاتصال الهاتفي",
    "Select a region" : "اختر منطقة",
    "Search …" : "البحث …",
    "Message without mention" : "رسالة بدون إشارة",
    "Mention myself" : "إشارة إليّ",
    "Mention everyone" : "أشِر إلى الجميع",
    "Select a conversation" : "إختَر مُحادثةً",
    "Select a mode" : "إختَر وضعيةً",
    "You do not have permissions to access this conversation." : "أنت ليس لديك الصلاحية للوصول إلى هذه المحادثة",
    "Join a different conversation or start a new one." : "التحق بمحادثة أخرى أو ابدأ محادثة جديدة",
    "The conversation does not exist" : "المحادثة غير موجودة",
    "Join a conversation or start a new one!" : "انضم لمحادثة او ابدء محادثة جديدة!",
    "Creating and joining a conversation with \"{userid}\"" : "إنشاء و انضمام إلى محادثة مع \"{userid}\"",
    "Join a conversation or start a new one" : "انضم لمحادثة او ابدء محادثة جديدة",
    "Error while joining the conversation" : "حدث خطأ أثناء الانضمام إلى المحادثة",
    "Nextcloud URL" : "رابط الخادم السحابي نكست كلاود",
    "Nextcloud user" : "عضو نكست كلاود",
    "User password" : "كلمة مرور المستخدم",
    "Talk conversation" : "محادثات",
    "Skip TLS verification" : "تجاهل تحقق من TLS",
    "Matrix server URL" : "عنوان URL لخادم Matrix",
    "User" : "المستخدم",
    "Matrix channel" : "قناة Matrix",
    "Mattermost server URL" : "عنوان URL لخادم Mattermost",
    "Mattermost user" : "مستخدم Mattermost",
    "Team name" : "اسم الفريق",
    "Channel name" : "اسم القناة",
    "Rocket.Chat server URL" : "عنوان URL لخادم Rocket.Chat",
    "User name or email address" : "اسم المستخدم او البريد الالكتروني",
    "Rocket.Chat channel" : "قناة Rocket.Chat  ",
    "Zulip server URL" : "عنوان URL لخادم Zulip ",
    "Bot user name" : "اسم المستخدم البوت ",
    "Bot API key" : "مفتاح Bot API",
    "Zulip channel" : "قناة Zulip",
    "API token" : "رمز API",
    "Slack channel" : "قناة سلاك Slack",
    "Server ID or name" : "معرف الخادم السحابي او الاسم",
    "Channel ID (prefixed with \"ID:\") or name" : "مُعرِّف القناة (مسبوقاً بـ \"ID:\") أو اسمها",
    "Channel" : "قناة",
    "Login" : "الدخول",
    "Chat ID" : "معرف المحادثة",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "عنوان URL لخادم IRC (مثل chat.freenode.net:6667)",
    "Nickname" : "كنية.\nلقب.",
    "Connection password" : "كلمة مرور الاتصال",
    "IRC channel" : "قناة IRC",
    "Channel password" : "كلمة مرور القناة",
    "NickServ nickname" : "اللقب لـ NickServ",
    "NickServ password" : "كلمة المرور لـ NickServ",
    "Use TLS" : "استخدم TLS",
    "Use SASL" : "استخدم SASL",
    "Tenant ID" : "معرف المستأجر",
    "Client ID" : "معرف العميل",
    "Team ID" : "معرف الفريق",
    "Thread ID" : "معرف الموضوع",
    "XMPP/Jabber server URL" : "عنوان URL لخادم XMPP/Jabber",
    "MUC server URL" : "عنوان URL لخادم MUC",
    "Jabber ID" : "معرف Jabber ",
    "Media" : "وسائط",
    "Polls" : "استطلاعات الرأي",
    "Deck cards" : "البطاقات",
    "Voice messages" : "الرسائل الصوتية",
    "Locations" : "المواقع",
    "Call recordings" : "تسجيلات المكالمات",
    "Audio" : "الصوت",
    "Show all media" : "عرض كل الوسائط",
    "Show all files" : "أظهر جميع الملفات",
    "Show all polls" : "عرض كل الاستبيانات",
    "Show all deck cards" : "عرض كل رزمة البطاقات",
    "Show all voice messages" : "عرض كافة الرسائل الصوتية",
    "Show all locations" : "عرض كل المواقع",
    "Show all call recordings" : "عرض جميع تسجيلات المكالمات",
    "Show all audio" : "عرض كل الأصوات",
    "Show all other" : "عرض كل الآخرين",
    "Group" : "المجموعة",
    "Team" : "الفريق",
    "You reconnected to the call" : "تمّت إعادة توصيلك بالمكالمة",
    "{actor} reconnected to the call" : "تمّت إعادة توصيل {actor} بالمكالمة",
    "You added {user0} and {user1}" : "أنت قمت بإضافة {user0} و  {user1}",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["أنت قمت بإضافة {user0} و {user1} و %n مشاركين آخرين","أنت قمت بإضافة {user0} و {user1} و %n مشاركين آخرين","أنت قمت بإضافة {user0} و {user1} و %n مشاركين آخرين","أنت قمت بإضافة {user0} و {user1} و %n مشاركين آخرين","أنت قمت بإضافة {user0} و {user1} و %n مشاركين آخرين","أنت قمت بإضافة {user0} و {user1} و %n مشاركين آخرين"],
    "An administrator added you and {user0}" : "قام مدير بإضافتك أنت و {user0}",
    "{actor} added you and {user0}" : "{actor} قام بإضافتك أنت و {user0}",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["قام المشرف بإضافتك أنت و {user0} و %n مشاركين آخرين","قام المشرف بإضافتك أنت و {user0} و %n مشاركين آخرين","قام المشرف بإضافتك أنت و {user0} و %n مساهمين آخرين","قام المشرف بإضافتك أنت و {user0} و %n مشاركين آخرين","قام المشرف بإضافتك أنت و {user0} و %n مشاركين آخرين","قام مدير بإضافتك أنت و {user0} و %n مشاركين آخرين"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} قام بإضافتك أنت و {user0} و %n مشاركين آخرين","{actor} قام بإضافتك أنت و {user0} و %n مشاركين آخرين","{actor} قام بإضافتك أنت و {user0} و %n مشاركين آخرين","{actor} قام بإضافتك أنت و {user0} و %n مشاركين آخرين","{actor} قام بإضافتك أنت و {user0} و %n مشاركين آخرين","{actor} قام بإضافتك أنت و {user0} و %n مشاركين آخرين"],
    "An administrator added {user0} and {user1}" : "قام مدير بإضافة {user0} و {user1}",
    "{actor} added {user0} and {user1}" : "{actor} قام بإضافة {user0} و {user1}",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["قام المشرف بإضافة {user0} و {user1} و %n مشاركين آخرين","قام المشرف بإضافة {user0} و {user1} و %n مشاركين آخرين","قام المشرف بإضافة {user0} و {user1} و %n مشاركين آخرين","قام المشرف بإضافة {user0} و {user1} و %n مشاركين آخرين","قام المشرف بإضافة {user0} و {user1} و %n مشاركين آخرين","قام مدير بإضافة {user0} و {user1} و %n مشاركين آخرين"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} قام بإضافة {user0} و {user1} و %n مشاركين آخرين","{actor} قام بإضافة {user0} و {user1} و %n مشاركين آخرين","{actor} قام بإضافة {user0} و {user1} و %n مشاركين آخرين","{actor} قام بإضافة {user0} و {user1} و %n مشاركين آخرين","{actor} قام بإضافة {user0} و {user1} و %n مشاركين آخرين","{actor} قام بإضافة {user0} و {user1} و %n مشاركين آخرين"],
    "You removed {user0} and {user1}" : "أنت قمت بحذف {user0} و {user1}",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["أنت قمت بحذف {user0}, و {user1}، و %n مشتركين آخرين","أنت قمت بحذف {user0}, و {user1}، و %n مشترك آخر ","أنت قمت بحذف {user0}, و {user1}، و %n مشتركين آخرين","أنت قمت بحذف {user0}, و {user1}، و %n مشتركين آخرين","أنت قمت بحذف {user0}, و {user1}، و %n مشترك آخر","أنت قمت بحذف {user0}, {user1} و %n مشاركين آخرين"],
    "An administrator removed you and {user0}" : "قام مدير بحذفك أنت و {user0}",
    "{actor} removed you and {user0}" : "{actor} قام بحذفك أنت و {user0}",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["قام المشرف بحذفك أنت, و {user0} و %n مشارك آخر","قام المشرف بحذفك أنت، و  {user0} و %n مشارك آخر","قام المشرف بحذفك أنت, و {user0} و %n مشاركين آخرين","قام المشرف بحذفك أنت, و {user0} و %n مشاركين آخرين","قام المشرف بحذفك أنت, و {user0} و %n مشاركين آخرين","قام مدير بحذفك أنت, و {user0} و %n مشاركين آخرين"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["قام {actor} بحذفك أنت, و {user0} و %n مشارك آخر","قام {actor} بحذفك أنت, و {user0} و %n مشارك آخر","قام {actor} بحذفك أنت, و {user0} و %n مشاركين آخرين","قام {actor} بحذفك أنت, و {user0} و %n مشاركين آخرين","قام {actor} بحذفك أنت, و {user0} و %n مشاركين آخرين","قام {actor} بحذفك أنت, و {user0} و%n مشاركين آخرين"],
    "An administrator removed {user0} and {user1}" : "قام مدير بحذف {user0} و {user1}",
    "{actor} removed {user0} and {user1}" : "قام {actor} بحذف {user0} و {user1}",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["قام المشرف بحذف {user0}, و {user1} و %n مشارك آخر","قام المشرف بحذف {user0}, و {user1} و %n مشارك آخر","قام المشرف بحذف {user0}, و {user1} و %n مشاركين آخرين","قام المشرف بحذف {user0}, و {user1} و %n مشاركين آخرين","قام المشرف بحذف {user0}, و {user1} و %n مشاركين آخرين","قام مدير بحذف {user0}, و {user1} و %n مشاركين آخرين"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["قام {actor} بحذف {user0}, و {user1} و %nمشارك آخر","قام {actor} بحذف {user0}, و {user1} و %n مشارك آخر","قام {actor} بحذف {user0}, و {user1} و %n مشاركين آخرين","قام {actor} بحذف {user0}, و {user1} و %n مشاركين آخرين","قام {actor} بحذف {user0}, و {user1} و %n مشاركين آخرين","قام {actor} بحذف {user0}, و {user1} و %n مشاركين آخرين"],
    "You and {user0} joined the call" : "لقد انضممت أنت و  {user0} للمكالمة",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["لقد انضممت أنت و {user0} و %n مشاركين آخرين للمكالمة","لقد انضممت أنت و {user0} و %n مشاركين آخرين للمكالمة","لقد انضممت أنت و {user0} و %n مشاركين آخرين للمكالمة","لقد انضممت أنت و {user0} و %n مشاركين آخرين للمكالمة","لقد انضممت أنت و {user0} و %n مشاركين آخرين للمكالمة","لقد انضممت أنت و {user0} و %n مشاركين آخرين للمكالمة"],
    "{user0} and {user1} joined the call" : "لقد انضم {user0} و {user1} إلى المكالمة",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["لقد انضم {user0} و {user1} و %n مشاركين آخرين للمكالمة","لقد انضم {user0} و {user1} و %n مشاركين آخرين للمكالمة","لقد انضم {user0} و {user1} و %n مشاركين آخرين للمكالمة","لقد انضم {user0} و {user1} و %n مشاركين آخرين للمكالمة","لقد انضم {user0} و {user1} و %n مشاركين آخرين للمكالمة","لقد انضم {user0} و {user1} و %n مشاركين آخرين للمكالمة"],
    "You and {user0} left the call" : "لقد غادرت أنت و {user0} المكالمة",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["لقد غادرت أنت و {user0} و %n مشاركون آخرين المكالمة","لقد غادرت أنت و {user0} و %n مشاركون آخرون المكالمة","لقد غادرت أنت و {user0} و %n مشاركون آخرون المكالمة","لقد غادرت أنت و {user0} و %n مشاركون آخرون المكالمة","لقد غادرت أنت و {user0} و %n مشاركون آخرون المكالمة","لقد غادرت أنت و {user0} و %n مشاركون آخرون المكالمة"],
    "{user0} and {user1} left the call" : "لقد غادر {user0} و {user1} المكالمة",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["لقد غادر {user0} و {user1} و %n مشاركون آخرون المكالمة","لقد غادر {user0} و {user1} و %n مشاركون آخرون المكالمة","لقد غادر {user0} و {user1} و %n مشاركون آخرون المكالمة","لقد غادر {user0} و {user1} و %n مشاركون آخرون المكالمة","لقد غادر {user0} و {user1} و %n مشاركون آخرون المكالمة","لقد غادر {user0} و {user1} و %n مشاركون آخرون المكالمة"],
    "You promoted {user0} and {user1} to moderators" : "لقد قمت أنت بترقية {user0} و  {user1} إلى مشرف",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["لقد قمت أنت بترقية {user0} و {user1} و %n مشاركين آخرين كمنسقين","لقد قمت أنت بترقية {user0} و {user1} و %n مشاركين آخرين إلى مشرفين","لقد قمت أنت بترقية {user0} و {user1} و %n مشاركين آخرين إلى مشرفين","لقد قمت أنت بترقية {user0} و {user1} و %n مشاركين آخرين إلى مشرفين","لقد قمت أنت بترقية {user0} و {user1} و %n مشاركين آخرين إلى مشرفين","لقد قمت أنت بترقية {user0} و {user1} و %n مشاركين آخرين إلى مشرفين"],
    "An administrator promoted you and {user0} to moderators" : "قام مدير بترقيتك أنت و {user0} إلى مشرفين",
    "{actor} promoted you and {user0} to moderators" : "قام {actor} بترقيتك أنت و {user0} إلى مشرفين",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["قام مدير بترقيتك أنت و {user0} و %n مشاركين آخرين كمشرفين","قام مدير بترقيتك أنت و {user0} و %n مشاركين آخرين كمشرفين","قام مدير بترقيتك أنت و {user0} و %n مشاركين آخرين كمشرفين","قام مدير بترقيتك أنت و {user0} و %n مشاركين آخرين كمشرفين","قام مدير بترقيتك أنت و {user0} و %n مشاركين آخرين كمشرفين","قام مدير بترقيتك أنت و {user0} و %n مشاركين آخرين كمشرفين"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["قام {actor} بترقيتك أنت و {user0} و %n مشاركين آخرين كمشرفين","قام {actor} بترقيتك أنت و {user0} و %n مشاركين آخرين كمشرفين","قام {actor} بترقيتك أنت و {user0} و %n مشاركين آخرين كمشرفين","قام {actor} بترقيتك أنت و {user0} و %n مشاركين آخرين كمشرفين","قام {actor} بترقيتك أنت و {user0} و %n مشاركين آخرين كمشرفين","قام {actor} بترقيتك أنت و {user0} و %n مشاركين آخرين كمشرفين"],
    "An administrator promoted {user0} and {user1} to moderators" : "قام مدير بترقية{user0} و {user1} إلى مشرفين",
    "{actor} promoted {user0} and {user1} to moderators" : "قام {actor} بترقية {user0} و {user1} إلى مشرفين",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["قام مدير بترقية {user0} و {user1} و %n مشاركين آخرين إلى مشرفين","قام مدير بترقية {user0} و {user1} و %n مشاركين آخرين إلى مشرفين","قام مدير بترقية {user0} و {user1} و %n مشاركين آخرين إلى مشرفين","قام مدير بترقية {user0} و {user1} و %n مشاركين آخرين إلى مشرفين","قام مدير بترقية {user0} و {user1} و %n مشاركين آخرين إلى مشرفين","قام مدير بترقية {user0} و  {user1} و %n مشاركين آخرين إلى مشرفين"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["قام {actor} بترقية{user0} و {user1} و %n مشاركين آخرين  إلى مشرفين","قام {actor} بترقية{user0} و {user1} و %n مشاركين آخرين  إلى مشرفين","قام {actor} بترقية{user0} و {user1} و %n مشاركين آخرين  إلى مشرفين","قام {actor} بترقية{user0} و {user1} و %n مشاركين آخرين  إلى مشرفين","قام {actor} بترقية{user0} و {user1} و %n مشاركين آخرين  إلى مشرفين","تقام {actor} بترقية{user0} و {user1} و %n مشاركين آخرين إلى مشرفين"],
    "You demoted {user0} and {user1} from moderators" : "لقد قمت بإلغاء ترقية {user0} و {user1} كمشرفين",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["أنت قمت بإلغاء ترقية {user0} و {user1} و %n مشاركين آخرين كمشرفين","أنت قمت بإلغاء ترقية {user0} و {user1} و %n مشاركين آخرين كمشرفين","أنت قمت بإلغاء ترقية {user0} و {user1} و %n مشاركين آخرين كمشرفين","أنت قمت بإلغاء ترقية {user0} و {user1} و %n مشاركين آخرين كمشرفين","أنت قمت بإلغاء ترقية {user0} و {user1} و %n مشاركين آخرين كمشرفين","أنت قمت بإلغاء ترقية {user0} و {user1} و %n مشاركين آخرين كمشرفين"],
    "An administrator demoted you and {user0} from moderators" : "لقد قام مدير بإلغاء ترقيتك أنت و {user0} كمشرفين",
    "{actor} demoted you and {user0} from moderators" : "لقد قام {actor} بإلغاء ترقيتك أنت و {user0} كمشرفين",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["لقد قام مدير بإلغاء ترقيتك أنت و {user0} و %n مشاركين آخرين كمشرفين","لقد قام مدير بإلغاء ترقيتك أنت و {user0} و %n مشاركين آخرين كمشرفين","لقد قام مدير بإلغاء ترقيتك أنت و {user0} و %n مشاركين آخرين كمشرفين","لقد قام مدير بإلغاء ترقيتك أنت و {user0} و %n مشاركين آخرين كمشرفين","لقد قام مدير بإلغاء ترقيتك أنت و {user0} و %n مشاركين آخرين كمشرفين","لقد قام مدير بإلغاء ترقيتك أنت و  {user0} و %n مشاركين آخرين كمشرفين"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["لقد قام {actor} بإلغاء ترقيتك أنت و {user0} و %n مشاركين آخرين كمشرفين","لقد قام {actor} بإلغاء ترقيتك أنت و {user0} و %n مشاركين آخرين كمشرفين","لقد قام {actor} بإلغاء ترقيتك أنت و {user0} و %n مشاركين آخرين كمشرفين","لقد قام {actor} بإلغاء ترقيتك أنت و {user0} و %n مشاركين آخرين كمشرفين","لقد قام {actor} بإلغاء ترقيتك أنت و {user0} و %n مشاركين آخرين كمشرفين","لقد قام {actor} بإلغاء ترقيتك أنت و {user0} و %n مشاركين آخرين كمشرفين"],
    "An administrator demoted {user0} and {user1} from moderators" : "لقد قام مدير بإلغاء ترقية {user0} و {user1} كمشرفين",
    "{actor} demoted {user0} and {user1} from moderators" : "لقد قام {actor} بإلغاء ترقية {user0} و {user1} كمشرفين",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["لقد قام مدير بإلغاء ترقية {user0} و {user1} و %n مشاركين آخرين كمشرفين","لقد قام مدير بإلغاء ترقية {user0} و {user1} و %n مشاركين آخرين كمشرفين","لقد قام مدير بإلغاء ترقية {user0} و {user1} و %n مشاركين آخرين كمشرفين","لقد قام مدير بإلغاء ترقية {user0} و {user1} و %n مشاركين آخرين كمشرفين","لقد قام مدير بإلغاء ترقية {user0} و {user1} و %n مشاركين آخرين كمشرفين","لقد قام مدير بإلغاء ترقية {user0} و {user1} و %n مشاركين آخرين كمشرفين"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["لقد قام {actor} بإلغاء ترقية {user0} و {user1} و %n مساهمين آخرين كمشرفين","لقد قام {actor} بإلغاء ترقية {user0} و {user1} و %n مساهمين آخرين كمشرفين","لقد قام {actor} بإلغاء ترقية {user0} و {user1} و %n مساهمين آخرين كمشرفين","لقد قام {actor} بإلغاء ترقية {user0} و {user1} و %n مساهمين آخرين كمشرفين","لقد قام {actor} بإلغاء ترقية {user0} و {user1} و %n مساهمين آخرين كمشرفين","لقد قام {actor} بإلغاء ترقية {user0} و {user1} و %n مشاركين آخرين كمشرفين"],
    "You: {lastMessage}" : "أنت: {lastMessage}",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "(edited by you)" : "(معدّلة بواسطتك)",
    "(edited by a deleted user)" : "(تمّ تحريرها من قِبَل مُستخدِم محذوف)",
    "(edited by {moderator})" : "(معدّلة بواسطة {moderator})",
    "The recording failed. Please contact your administrator." : "فشل التسجيل. الرجاء الاتصال بمسؤول النظام.",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "انضممت لمحادثة آخرى في نافذة او جهاز آخر. هذه الخاصية غير مدعومة سيتم اغلاق هذه الجلسة من قبل نكست كلاود التحدث. ماذا تريد ان تفعل؟",
    "Leave this page" : "مغادرة هذه الصفحة",
    "Join here" : "انضم لهذا",
    "Deck card has been posted to {conversation}" : "بطاقات تمّ نشرها في {conversation}",
    "An error occurred while posting deck card to conversation" : "حدث خطأ أثناء نشر كَدْسَة البطاقات إلى المحادثة",
    "Post to a conversation" : "انشر في محادثة ",
    "Post to conversation" : "انشر في محادثة ",
    "Location has been posted to {conversation}" : "تم نشر الموقع في {conversation}",
    "An error occurred while posting location to conversation" : "حدث خطأ أثناء نشر الموقع في المحادثة",
    "Share to a conversation" : "شارِك في مُحادَثة",
    "Share to conversation" : "شارِك في المُحادثَة",
    "In conversation" : "في المحادثة ...",
    "Search in conversation: {conversation}" : "البحث في المحادثة: {conversation}",
    "Your requests are throttled at the moment due to brute force protection" : "يتم تقييد طلباتك في الوقت الحالي كإجراء تحسبي للحماية من هجمات القوة الغاشمة",
    "Error while clearing conversation history" : "خطأ أثناء مسح محفوظات المحادثة",
    "Error occurred while allowing guests" : "حدث خطأ أثناء السماح للضيوف ",
    "Error occurred while disallowing guests" : "حدث خطأ أثناء عدم السماح للضيوف ",
    "Error occurred when restricting the conversation to moderator" : "حدث خطأ عندما اقتصرت المحادثة على المشرفيين فقط ",
    "Error occurred when opening the conversation to everyone" : "حدث خطأ أثناء فتح المحادثة للجميع ",
    "Conversation password has been saved" : "تم حفظ كلمة المرور للمحادثة ",
    "Conversation password has been removed" : "حُذفت كلمة المرور للمحادثة ",
    "Error occurred while saving conversation password" : "حدث خطأ أثناء حفظ كلمة السر للمحادثة ",
    "Call recording is starting." : "بدء تسجيل المكالمة.",
    "Call recording stopped while starting." : "تسجيل المكالمة توقف بمجرد البدء فيه",
    "Call recording stopped. You will be notified once the recording is available." : "توقف تسجيل المكالمات. سيتم إخطارك بمجرد إتاحة التسجيل.",
    "Conversation picture set" : "تمّ تعيين صورة المحادثة",
    "Conversation picture deleted" : "تمّ حذف صورة المحادثة",
    "Could not delete the conversation picture" : "تعذر حذف صورة المحادثة",
    "Could not post message: {errorMessage}" : "لا يمكن نشر رسالة: {errorMessage}",
    "Participant is banned successfully" : "تمّ حظر المُشارِك بنجاحٍ",
    "Error while banning the participant" : "حدث خطأ أثناء حظر المُشارك",
    "An error occurred while fetching the participants" : "حدث خطأ اثناء اضافة مشاركيين",
    "Could not send invitation to {actorId}" : "تعذر إرسال دعوة إلى {actorId} ",
    "Invitations sent" : "تم إرسال الدعوات ",
    "Error occurred when sending invitations" : "حدث خطأ أثناء إرسال الدعوات ",
    "Failed to join the conversation." : "تعذّر الانضمام إلى المحادثة.",
    "An error occurred while creating breakout rooms" : "حدث خطأ أثناء إنشاء الغرف الجانبية",
    "An error occurred while re-ordering the attendees" : "حدث خطأٌ أثناء إعادة ترتيب الحاضرين",
    "An error occurred while deleting breakout rooms" : "حدث خطأ أثناء حذف الغرف الجانبية",
    "An error occurred while starting breakout rooms" : "حدث خطأ أثناء بدء الغرف الجانبية",
    "An error occurred while stopping breakout rooms" : "حدث خطأ أثناء إيقاف الغرف الجانبية",
    "An error occurred while sending a message to the breakout rooms" : "حدث خطأ أثناء إرسال رسالة إلى الغرف الجانبية",
    "An error occurred while requesting assistance" : "حدث خطأٌ أثناء طلب المساعدة",
    "An error occurred while resetting the request for assistance" : "حدث خطأٌ أثناء إعادة تعيين طلب المساعدة",
    "An error occurred while joining breakout room" : "حدث خطأٌ أثناء الانضمام إلى غرفة جانبية",
    "An error occurred while accepting an invitation" : "حدث خطأ أثناء قبول الدعوة",
    "An error occurred while rejecting an invitation" : "حدث خطأ أثناء رفض الدعوة",
    "{guest} (guest)" : "{guest} (ضيف)",
    "Poll draft has been saved" : "تمّ حفظ مسودة الاستبيان",
    "An error occurred while saving the draft" : "حدث خطأ أثناء حفظ المسودة",
    "An error occurred while submitting your vote" : "حدث خطأ أثناء تقديم تصويتك",
    "An error occurred while ending the poll" : "حدث خطأ أثناء إنهاء الاستطلاع",
    "An error occurred while deleting the poll draft" : "حدث خطأ أثناء حذف مسودة الاستطلاع",
    "Poll \"{name}\" was created by {user}. Click to vote" : "الاستفتاء \"{name}\" أنشأه {user}. أنقُر للتصويت",
    "Failed to add reaction" : "فشل في إضافة تفاعل",
    "Failed to remove reaction" : "فشل في إزالة تفاعل",
    "Error while uploading file \"{fileName}\"" : "حدث خطأ أثناء رفع الملف \"{fileName}\"",
    "Not enough free space to upload file \"{fileName}\"" : "لا يوجد مساحة تخزينية كافية لرفع الملف \"{fileName}\"",
    "You are not allowed to share files" : "غير مسموح لك بمشاركة الملفات ",
    "Error while sharing file" : "خطأ اثناء مشاركة ملف",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "تستخدم متصفح غير مدعوم بالكامل من قبل نكست كلاود التحدث. استخدم اخر اصدار من فايرفوكس، مايكروسوفت ادج، قوقل كروم أو ابل سفاري.",
    "_%n hour_::_%n hours_" : ["%nساعات","%n ساعة","%n ساعات","%n ساعات","%n ساعات","%n ساعات"],
    "_%n day_::_%n days_" : ["%n أيام","%n يوم","%nأيام","%nأيام","%n أيام","%n أيام"],
    "_%n week_::_%n weeks_" : ["%n أسابيع","%n أسبوع","%n أسابيع","%n أسابيع","%n أسابيع","%n أسابيع"],
    "_In %n hour_::_In %n hours_" : ["في %n ساعة","في %n ساعة","في %n ساعة","في %n ساعات","في %n ساعة","في %n ساعة"],
    "_%n minute _::_%n minutes_" : ["%n دقيقة","%n دقيقة","%n دقيقة","%n دقائق","%n دقيقة","%n دقيقة"],
    "In {hours} and {minutes}" : "في {hours} و {minutes}",
    "_In %n minute_::_In %n minutes_" : ["في %n دقيقة","في %n دقيقة","في %n دقيقة","في %n دقائق","في %n دقيقة","في %n دقيقة"],
    "Later today – {timeLocale}" : "في وقت لاحقٍ اليوم – {timeLocale}",
    "Tomorrow – {timeLocale}" : "غداً – {timeLocale}",
    "This weekend – {timeLocale}" : "نهاية هذا الأسبوع – {timeLocale}",
    "Next week – {timeLocale}" : "الأسبوع القادم – {timeLocale}",
    "Message link copied to clipboard" : "تمّ نسخ رابط الرسالة إلى الحافظة",
    "Conversation link copied to clipboard" : "تمّ نسخ رابط المحادثة إلى الحافظة",
    "The link could not be copied" : "لا يمكن نسخ الرابط",
    "Error while parsing a PROPFIND error" : "حدث خطأ أثناء تحليل PROFIND",
    "Sending signaling message has failed" : "فشل إرسال رسالة الإشارة",
    "Lost connection to signaling server. Trying to reconnect." : "انقطع الاتصال بخادم التشوير. حاول معاودة الاتصال.",
    "Lost connection to signaling server." : "فُقِد الاتصال بخادوم الإشارة.",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "يجب تحديث خادم الإشارة الذي تم تكوينه حتى يكون متوافقًا مع هذا الإصدار من تطبيق Talk. يرجى الاتصال بإدارتك.",
    "Please restart the app." : "يُرجى إعادة تشغيل التطبيق.",
    "Please reload the page." : "رجاء أعد تحميل الصفحة.",
    "Please try to restart the app." : "حاول رجاءً إعادة تشغيل التطبيق.",
    "Please try to reload the page." : "حاول رجاءً إعادة تحميل الصفحة.",
    "Do not disturb" : "عدم الازعاج",
    "Away" : "بالخارج",
    "Microphone {number}" : "مايك {number}",
    "Camera {number}" : "كاميرا {number}",
    "Speaker {number}" : "المتحدث {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "تتحدث في وضع كاتم الصوت، يرجى تعطيل كاتم الصوت ليتمكن الآخرين من سماعك.",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "تعذر إنشاء اتصال مع مشارك واحد على الأقل. لمثل هذا السيناريو قد تكون بحاجه إلى خادم TURN. يرجى مطالبة المسؤول تعيين  {linkstart} هذه الوثائق {linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "يستغرق هذا وقتًا أطول من المعتاد. هل تم بالفعل منح أذونات الوسائط (أو رفضها)؟ إذا كانت الإجابة بنعم ، يرجى إعادة تشغيل المتصفح ، لأنه فشل الوصول للصوت والفيديو ",
    "Access to microphone & camera is only possible with HTTPS" : "الوصول للمايك والكاميرا مسموح فقط في HTTPS",
    "Please move your setup to HTTPS" : "يرجى تعديل تعيين إلى HTTPS",
    "Access to microphone & camera was denied" : "تم رفض الوصول للمايكرفون والكاميرا",
    "WebRTC is not supported in your browser" : "WebRTC غير مدعوم في متصفحك",
    "Please use a different browser like Firefox or Chrome" : "يرجى استخدام متصفح آخر مثل فايرفوكس او كروم",
    "Error while accessing microphone & camera" : "خطأ في الوصول للمايكرفون والكاميرا",
    "%s Talk on your mobile devices" : "%s محادثة في جهازك المحمول",
    "Join conversations at any time, anywhere, on any device." : "انضم إلى المحادثات في أي وقت و من أي مكان و عبر أي جهاز",
    "Android app" : "تطبيق الأندرويد",
    "iOS app" : "تطبيق آي أواس",
    "__language_name__" : "__اسم اللغة__",
    "Webhook Demo" : "عرض توضيحي demo لخطّاف الوِب Webhook",
    "Call summary (%s)" : "ملخص المكالمة (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "يقوم روبوت \"ملخص المكالمة\"بنشر رسالة عامة بعد المكالمة يسرد فيها جميع المشاركين و يحدد المهام",
    "Tasks" : "المهام",
    "Notes" : "الملاحظات",
    "Reports" : "تقارير",
    "Decisions" : "قرارات",
    "Agenda" : "الأجندة",
    "Call summary" : "ملخص المكالمة",
    "Call summary - {title}" : "ملخص المكالمة - {title}",
    "Talk to %s" : "تحدث إلى %s",
    "Talk conversation for event" : "محادثة الحدث ",
    "Client Push is installed, this improves the performance of desktop clients." : "تمّ تثبيت Client Push دفع المعلومات من جهة العميل؛ هذا سيؤدي لتحسين أداء عملاء سطح المكتب. ",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push} غير مُثبَّت. هذا قد يتسبب في مشاكل في الأداء عند استعمال عملاء سطح المكتب.",
    "Next meeting" : "الاجتماع التالي",
    "Join conversations from remote Nextcloud servers" : "الانضمام إلى المحادثة من خوادم بعيدة لنكست كلاود",
    "Your default media state has been saved" : "تمّ حفظ حالة الوسائط الخاصة بك",
    "Set reminder for later today" : "عيّن التذكير لوقت لاحقٍ اليوم",
    "Set reminder for tomorrow" : "عيّن التذكير للغد",
    "Set reminder for this weekend" : "عيّن التذكير لنهاية هذا الأسبوع",
    "Set reminder for next week" : "عيّن التذكير للأسبوع القادم",
    "Generate summary" : "توليد مُلخَّص",
    "Open poll • You voted already" : "فتح الاستطلاع • لقد قمت بالتصويت بالفعل",
    "Open poll • Click to vote" : "فتح الاستطلاع • اضغط للتصويت",
    "Poll • Ended" : "انتهى•الاستطلاع",
    "Talk recording from {time} ({conversation})" : "تسجيل حديث من {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["نتائج الاستطلاع • %n أصوات","نتائج الاستطلاع • %n صوت","نتائج الاستطلاع • %n أصوات","نتائج الاستطلاع • %n أصوات","نتائج الاستطلاع • %n أصوات","نتائج الاستطلاع • %nأصوات"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["فتح استطلاع • %n أصوات","فتح استطلاع • %n صوت","فتح استطلاع • %n أصوات","فتح استطلاع • %n أصوات","فتح استطلاع • %n أصوات","فتح استطلاع •%n أصوات"],
    "Submit vote" : "إرسال التصويت",
    "Your privacy setting has been saved" : "تم حفظ إعدادات الخصوصية الخاصة بك ",
    "Your personal setting has been saved" : "تمّ حفظ إعداداتك الشخصية",
    "Failed to save sounds setting" : "فشل حفظ إعدادت الصوت ",
    "Sounds setting saved" : "تم حفظ إعدادات الأصوات ",
    "Nextcloud Talk was updated, you cannot start or join a call." : "تمّ تحديث \"المحادثة\" من نكست كلاود. لايمكنك البدء في أو الانضمام إلى محادثة.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "انضممت لمحادثة آخرى في نافذة او جهاز آخر. هذه الخاصية غير مدعومة سيتم اغلاق هذه الجلسة من قبل نكست كلاود التحدث.",
    "Nextcloud Talk was updated." : "تمّ تحديث \"المحادثة\" من نكست كلاود.",
    "Nextcloud is in maintenance mode." : "نكست كلاود في وضعية الصيانة.",
    "Nextcloud Talk Federation was updated." : "تمّ تحديث \"المحادثة الاتحادية\" Talk Federation من نكست كلاود."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
